@@ -5,11 +5,13 @@ from typing import Dict, List, Optional, Union
 from ruamel.yaml.comments import CommentedMap
 
 from great_expectations.checkpoint.util import (
-    batch_request_contains_batch_data,
     batch_request_in_validations_contains_batch_data,
-    get_batch_request_as_dict,
     get_validations_with_batch_request_as_dict,
 )
+from great_expectations.core.batch import (
+    batch_request_contains_batch_data,
+    get_batch_request_as_dict,
+)
 from great_expectations.data_context.types.base import (
     CheckpointConfig,
     checkpointConfigSchema,
@@ -159,8 +161,10 @@ class SimpleCheckpointConfigurator:
         }
         config_kwargs.update(specific_config_kwargs_overrides)
 
-        # Roundtrip through schema validation to add any missing fields
-        checkpoint_config: CommentedMap = checkpointConfigSchema.load(config_kwargs)
+        # Roundtrip through schema validation to remove any illegal fields add/or restore any missing fields.
+        checkpoint_config: dict = checkpointConfigSchema.load(
+            CommentedMap(**config_kwargs)
+        )
         config_kwargs = checkpointConfigSchema.dump(checkpoint_config)
 
         logger.debug(
