@@ -9,9 +9,13 @@ from typing import List, Optional, Union
 import requests
 
 import great_expectations.exceptions as ge_exceptions
-from great_expectations.core.batch import BatchRequest, RuntimeBatchRequest
-from great_expectations.core.util import nested_update, safe_deep_copy
-from great_expectations.util import filter_properties_dict
+from great_expectations.core.batch import (
+    BatchRequest,
+    RuntimeBatchRequest,
+    get_batch_request_as_dict,
+    materialize_batch_request,
+)
+from great_expectations.core.util import nested_update
 
 logger = logging.getLogger(__name__)
 
@@ -32,21 +36,14 @@ def send_slack_notification(
     try:
         response = session.post(url=url, headers=headers, json=query)
     except requests.ConnectionError:
-        logger.warning(
-            "Failed to connect to Slack webhook at {url} "
-            "after {max_retries} retries.".format(url=slack_webhook, max_retries=10)
-        )
+        logger.warning(f"Failed to connect to Slack webhook after {10} retries.")
     except Exception as e:
         logger.error(str(e))
     else:
         if response.status_code != 200:
             logger.warning(
-                "Request to Slack webhook at {url} "
-                "returned error {status_code}: {text}".format(
-                    url=slack_webhook,
-                    status_code=response.status_code,
-                    text=response.text,
-                )
+                "Request to Slack webhook "
+                f"returned error {response.status_code}: {response.text}"
             )
 
         else:
@@ -57,19 +54,13 @@ def send_slack_notification(
 def send_opsgenie_alert(query, suite_name, settings):
     """Creates an alert in Opsgenie."""
     if settings["region"] is not None:
-        url = "https://api.{region}.opsgenie.com/v2/alerts".format(
-            region=settings["region"]
-        )  # accommodate for Europeans
+        url = f"https://api.{settings['region']}.opsgenie.com/v2/alerts"  # accommodate for Europeans
     else:
         url = "https://api.opsgenie.com/v2/alerts"
 
-    headers = {
-        "Authorization": "GenieKey {api_key}".format(api_key=settings["api_key"])
-    }
+    headers = {"Authorization": f"GenieKey {settings['api_key']}"}
     payload = {
-        "message": "Great Expectations suite {suite_name} failed".format(
-            suite_name=suite_name
-        ),
+        "message": f"Great Expectations suite {suite_name} failed",
         "description": query,
         "priority": settings["priority"],  # allow this to be modified in settings
     }
@@ -85,12 +76,8 @@ def send_opsgenie_alert(query, suite_name, settings):
     else:
         if response.status_code != 202:
             logger.warning(
-                "Request to Opsgenie API at {url} "
-                "returned error {status_code}: {text}".format(
-                    url=url,
-                    status_code=response.status_code,
-                    text=response.text,
-                )
+                "Request to Opsgenie API "
+                f"returned error {response.status_code}: {response.text}"
             )
         else:
             return "success"
@@ -102,23 +89,15 @@ def send_microsoft_teams_notifications(query, microsoft_teams_webhook):
     try:
         response = session.post(url=microsoft_teams_webhook, json=query)
     except requests.ConnectionError:
-        logger.warning(
-            "Failed to connect to Microsoft Teams webhook at {url} "
-            "after {max_retries} retries.".format(
-                url=microsoft_teams_webhook, max_retries=10
-            )
-        )
+        logger.warning("Failed to connect to Microsoft Teams webhook after 10 retries.")
+
     except Exception as e:
         logger.error(str(e))
     else:
         if response.status_code != 200:
             logger.warning(
-                "Request to Microsoft Teams webhook at {url} "
-                "returned error {status_code}: {text}".format(
-                    url=microsoft_teams_webhook,
-                    status_code=response.status_code,
-                    text=response.text,
-                )
+                "Request to Microsoft Teams webhook "
+                f"returned error {response.status_code}: {response.text}"
             )
             return
         else:
@@ -131,30 +110,18 @@ def send_webhook_notifications(query, webhook, target_platform):
         response = session.post(url=webhook, json=query)
     except requests.ConnectionError:
         logger.warning(
-            "Failed to connect to {target_platform} webhook at {url} "
-            "after {max_retries} retries.".format(
-                url=webhook,
-                max_retries=10,
-                target_platform=target_platform,
-            )
+            f"Failed to connect to {target_platform} webhook after 10 retries."
         )
     except Exception as e:
         logger.error(str(e))
     else:
         if response.status_code != 200:
             logger.warning(
-                "Request to {target_platform} webhook at {url} "
-                "returned error {status_code}: {text}".format(
-                    url=webhook,
-                    status_code=response.status_code,
-                    target_platform=target_platform,
-                    text=response.text,
-                )
+                f"Request to {target_platform} webhook "
+                f"returned error {response.status_code}: {response.text}"
             )
         else:
-            return "{target_platform} notification succeeded.".format(
-                target_platform=target_platform
-            )
+            return f"{target_platform} notification succeeded."
 
 
 # noinspection SpellCheckingInspection
@@ -224,10 +191,12 @@ def get_substituted_validation_dict(
         "evaluation_parameters": nested_update(
             substituted_runtime_config.get("evaluation_parameters") or {},
             validation_dict.get("evaluation_parameters", {}),
+            dedup=True,
         ),
         "runtime_configuration": nested_update(
             substituted_runtime_config.get("runtime_configuration") or {},
             validation_dict.get("runtime_configuration", {}),
+            dedup=True,
         ),
     }
     if validation_dict.get("name") is not None:
@@ -261,17 +230,6 @@ def get_substituted_batch_request(
         batch_request=substituted_runtime_batch_request
     )
 
-    effective_batch_request: dict = dict(
-        **substituted_runtime_batch_request, **validation_batch_request
-    )
-
-    batch_request_class: type
-
-    if "runtime_parameters" in effective_batch_request:
-        batch_request_class = RuntimeBatchRequest
-    else:
-        batch_request_class = BatchRequest
-
     for key, value in validation_batch_request.items():
         substituted_value = substituted_runtime_batch_request.get(key)
         if value is not None and substituted_value is not None:
@@ -279,15 +237,11 @@ def get_substituted_batch_request(
                 f'BatchRequest attribute "{key}" was specified in both validation and top-level CheckpointConfig.'
             )
 
-    # noinspection PyUnresolvedReferences
-    filter_properties_dict(
-        properties=effective_batch_request,
-        keep_fields=batch_request_class.field_names,
-        clean_nulls=False,
-        inplace=True,
+    effective_batch_request: dict = dict(
+        **substituted_runtime_batch_request, **validation_batch_request
     )
 
-    return batch_request_class(**effective_batch_request)
+    return materialize_batch_request(batch_request=effective_batch_request)
 
 
 def substitute_template_config(source_config: dict, template_config: dict) -> dict:
@@ -318,6 +272,7 @@ def substitute_template_config(source_config: dict, template_config: dict) -> di
         updated_batch_request = nested_update(
             batch_request,
             source_config["batch_request"],
+            dedup=True,
         )
         dest_config["batch_request"] = updated_batch_request
     if source_config.get("action_list") is not None:
@@ -331,6 +286,7 @@ def substitute_template_config(source_config: dict, template_config: dict) -> di
         updated_evaluation_parameters = nested_update(
             evaluation_parameters,
             source_config["evaluation_parameters"],
+            dedup=True,
         )
         dest_config["evaluation_parameters"] = updated_evaluation_parameters
     if source_config.get("runtime_configuration") is not None:
@@ -338,6 +294,7 @@ def substitute_template_config(source_config: dict, template_config: dict) -> di
         updated_runtime_configuration = nested_update(
             runtime_configuration,
             source_config["runtime_configuration"],
+            dedup=True,
         )
         dest_config["runtime_configuration"] = updated_runtime_configuration
     if source_config.get("validations") is not None:
@@ -381,18 +338,13 @@ def substitute_runtime_config(source_config: dict, runtime_kwargs: dict) -> dict
     if runtime_kwargs.get("batch_request") is not None:
         batch_request = dest_config.get("batch_request") or {}
         batch_request_from_runtime_kwargs = runtime_kwargs["batch_request"]
-        batch_request_from_runtime_kwargs = safe_deep_copy(
-            data=batch_request_from_runtime_kwargs
+        batch_request_from_runtime_kwargs = get_batch_request_as_dict(
+            batch_request=batch_request_from_runtime_kwargs
         )
-        if isinstance(
-            batch_request_from_runtime_kwargs, (BatchRequest, RuntimeBatchRequest)
-        ):
-            # noinspection PyUnresolvedReferences
-            batch_request_from_runtime_kwargs = (
-                batch_request_from_runtime_kwargs.to_dict()
-            )
         updated_batch_request = nested_update(
-            batch_request, batch_request_from_runtime_kwargs
+            batch_request,
+            batch_request_from_runtime_kwargs,
+            dedup=True,
         )
         dest_config["batch_request"] = updated_batch_request
     if runtime_kwargs.get("action_list") is not None:
@@ -406,6 +358,7 @@ def substitute_runtime_config(source_config: dict, runtime_kwargs: dict) -> dict
         updated_evaluation_parameters = nested_update(
             evaluation_parameters,
             runtime_kwargs["evaluation_parameters"],
+            dedup=True,
         )
         dest_config["evaluation_parameters"] = updated_evaluation_parameters
     if runtime_kwargs.get("runtime_configuration") is not None:
@@ -413,6 +366,7 @@ def substitute_runtime_config(source_config: dict, runtime_kwargs: dict) -> dict
         updated_runtime_configuration = nested_update(
             runtime_configuration,
             runtime_kwargs["runtime_configuration"],
+            dedup=True,
         )
         dest_config["runtime_configuration"] = updated_runtime_configuration
     if runtime_kwargs.get("validations") is not None:
@@ -467,16 +421,6 @@ def get_updated_action_list(
     return list(base_action_list_dict.values())
 
 
-def batch_request_contains_batch_data(
-    batch_request: Optional[Union[BatchRequest, RuntimeBatchRequest, dict]] = None
-) -> bool:
-    return (
-        batch_request is not None
-        and batch_request.get("runtime_parameters") is not None
-        and batch_request["runtime_parameters"].get("batch_data") is not None
-    )
-
-
 def batch_request_in_validations_contains_batch_data(
     validations: Optional[List[dict]] = None,
 ) -> bool:
@@ -493,15 +437,6 @@ def batch_request_in_validations_contains_batch_data(
     return False
 
 
-def get_batch_request_as_dict(
-    batch_request: Optional[Union[BatchRequest, RuntimeBatchRequest, dict]] = None
-) -> Optional[dict]:
-    if isinstance(batch_request, (BatchRequest, RuntimeBatchRequest)):
-        batch_request = batch_request.to_dict()
-
-    return batch_request
-
-
 def get_validations_with_batch_request_as_dict(
     validations: Optional[list] = None,
 ) -> Optional[list]:
@@ -535,14 +470,12 @@ def send_cloud_notification(url: str, headers: dict):
     try:
         response = session.post(url=url, headers=headers)
     except requests.ConnectionError:
-        logger.error(
-            f"Failed to connect to Cloud backend at {url} " f"after {10} retries."
-        )
+        logger.error(f"Failed to connect to Cloud backend after {10} retries.")
     except Exception as e:
         logger.error(str(e))
     else:
         if response.status_code != 200:
-            message = f"Cloud Notification request at {url} returned error {response.status_code}: {response.text}"
+            message = f"Cloud Notification request returned error {response.status_code}: {response.text}"
             logger.error(message)
             return {"cloud_notification_result": message}
         else:
