@@ -5,11 +5,11 @@ from typing import List, Optional, Union
 
 from ruamel.yaml.comments import CommentedMap
 
-import great_expectations.checkpoint.toolkit as checkpoint_toolkit
 import great_expectations.exceptions as ge_exceptions
 from great_expectations import DataContext
 from great_expectations.checkpoint import Checkpoint, LegacyCheckpoint
 from great_expectations.cli.upgrade_helpers.base_upgrade_helper import BaseUpgradeHelper
+from great_expectations.data_context.store.checkpoint_store import CheckpointStore
 from great_expectations.data_context.types.base import (
     DataContextConfig,
     DataContextConfigDefaults,
@@ -63,7 +63,7 @@ class UpgradeHelperV13(BaseUpgradeHelper):
         self._process_validation_operators_for_checklist()
 
     def _process_checkpoint_store_for_checklist(self):
-        if checkpoint_toolkit.default_checkpoints_exist(
+        if CheckpointStore.default_checkpoints_exist(
             directory_path=self.data_context.root_directory
         ):
             config_commented_map: CommentedMap = (
@@ -115,7 +115,7 @@ class UpgradeHelperV13(BaseUpgradeHelper):
 
             if len(self.upgrade_checklist["manual"]["checkpoints"]) == 0:
                 self.upgrade_log["skipped_checkpoint_config_upgrade"] = True
-        except ge_exceptions.InvalidTopLevelConfigKeyError as e:
+        except ge_exceptions.InvalidTopLevelConfigKeyError:
             self.upgrade_log["skipped_checkpoint_config_upgrade"] = True
 
     # noinspection SpellCheckingInspection
@@ -175,7 +175,7 @@ class UpgradeHelperV13(BaseUpgradeHelper):
             and not self.upgrade_log["skipped_checkpoint_store_upgrade"]
         )
 
-        upgrade_overview = f"""\
+        upgrade_overview = """\
 <cyan>\
 ++====================================++
 || UpgradeHelperV13: Upgrade Overview ||
@@ -185,7 +185,7 @@ class UpgradeHelperV13(BaseUpgradeHelper):
 """
         if increment_version:
             upgrade_overview += (
-                f"""\
+                """\
 UpgradeHelperV13 will upgrade your project to be compatible with Great Expectations V3 API.
 """
                 + self._upgrade_overview_common_content(
@@ -203,12 +203,12 @@ more about the automated upgrade process:
 """
             )
             if confirmation_required:
-                upgrade_overview += f"""\
+                upgrade_overview += """\
 
 Would you like to proceed with the project upgrade?\
 """
         else:
-            upgrade_overview += f"""\
+            upgrade_overview += """\
 Your project needs to be upgraded in order to be compatible with Great Expectations V3 API.
 """ + self._upgrade_overview_common_content(
                 manual_steps_required=manual_steps_required
@@ -375,7 +375,7 @@ No manual upgrade steps are required.
     def _generate_upgrade_report(self):
         upgrade_log_path = self._save_upgrade_log()
         increment_version = self.upgrade_log["update_version"]
-        upgrade_report = f"""\
+        upgrade_report = """\
 <cyan>\
 ++================++
 || Upgrade Report ||
