@@ -9,6 +9,11 @@ import uuid
 
 import click
 
+try:
+    from pybigquery.parse_url import parse_url as parse_bigquery_url
+except (ImportError, ModuleNotFoundError):
+    parse_bigquery_url = None
+
 import great_expectations.exceptions as ge_exceptions
 from great_expectations import DataContext, rtd_url_ge_version
 from great_expectations.cli.v012 import toolkit
@@ -122,17 +127,15 @@ def delete_datasource(directory, datasource):
     try:
         context.delete_datasource(datasource)
     except ValueError:
-        cli_message(
-            "<red>{}</red>".format(f"Datasource {datasource} could not be found.")
-        )
+        cli_message(f"<red>Datasource {datasource} could not be found.</red>")
         sys.exit(1)
     try:
         context.get_datasource(datasource)
     except ValueError:
-        cli_message("<green>{}</green>".format("Datasource deleted successfully."))
+        cli_message("<green>Datasource deleted successfully.</green>")
         sys.exit(1)
     else:
-        cli_message("<red>{}</red>".format("Datasource not deleted."))
+        cli_message("<red>Datasource not deleted.</red>")
         sys.exit(1)
 
 
@@ -406,7 +409,7 @@ def _add_pandas_datasource(
         else:
             basenamepath = path
 
-        datasource_name = os.path.basename(basenamepath) + "__dir"
+        datasource_name = f"{os.path.basename(basenamepath)}__dir"
         if prompt_for_datasource_name:
             datasource_name = click.prompt(
                 msg_prompt_datasource_name, default=datasource_name
@@ -548,7 +551,7 @@ def _add_sqlalchemy_datasource(context, prompt_for_datasource_name=True):
             )
 
             configuration = SqlAlchemyDatasource.build_configuration(
-                credentials="${" + datasource_name + "}"
+                credentials=f"${{{datasource_name}}}"
             )
 
             configuration["class_name"] = "SqlAlchemyDatasource"
@@ -590,7 +593,7 @@ The credentials will be saved in uncommitted/config_variables.yml under the key
                     module_name="great_expectations.datasource",
                     class_name="SqlAlchemyDatasource",
                     data_asset_type={"class_name": "SqlAlchemyDataset"},
-                    credentials="${" + datasource_name + "}",
+                    credentials=f"${{{datasource_name}}}",
                 )
                 # TODO this message about continuing may not be accurate
                 cli_message(
@@ -770,7 +773,7 @@ def _collect_snowflake_credentials_key_pair():
 def _collect_bigquery_credentials(default_credentials=None):
     sqlalchemy_url = click.prompt(
         """What is the SQLAlchemy url/connection string for the BigQuery connection?
-(reference: https://github.com/mxmzdlv/pybigquery#connection-string-parameters)
+(reference: https://github.com/googleapis/python-bigquery-sqlalchemy#connection-string-parameters)
 """,
         show_default=False,
     ).strip()
@@ -901,7 +904,7 @@ def _add_spark_datasource(
         else:
             basenamepath = path
 
-        datasource_name = os.path.basename(basenamepath) + "__dir"
+        datasource_name = f"{os.path.basename(basenamepath)}__dir"
         if prompt_for_datasource_name:
             datasource_name = click.prompt(
                 msg_prompt_datasource_name, default=datasource_name
@@ -968,7 +971,7 @@ def select_batch_kwargs_generator(
             ]
         )
         option_selection = click.prompt(
-            msg_prompt_select_generator + "\n" + choices,
+            f"{msg_prompt_select_generator}\n{choices}",
             type=click.Choice(
                 [str(i) for i, generator_name in enumerate(generator_names, 1)]
             ),
@@ -1102,6 +1105,7 @@ We could not determine the format of the file. What is it?
     2. Parquet
     3. Excel
     4. JSON
+    5. SAS
 """
 
     reader_method_file_extensions = {
@@ -1109,6 +1113,7 @@ We could not determine the format of the file. What is it?
         "2": "parquet",
         "3": "xlsx",
         "4": "json",
+        "5": "sas",
     }
 
     data_asset_name = None
@@ -1201,13 +1206,13 @@ We could not determine the format of the file. What is it?
 
                 option_selection = click.prompt(
                     msg_prompt_file_type,
-                    type=click.Choice(["1", "2", "3", "4"]),
+                    type=click.Choice(["1", "2", "3", "4", "5"]),
                     show_choices=False,
                 )
 
                 try:
                     reader_method = datasource.guess_reader_method_from_path(
-                        path + "." + reader_method_file_extensions[option_selection]
+                        f"{path}.{reader_method_file_extensions[option_selection]}"
                     )["reader_method"]
                 except BatchKwargsError:
                     pass
@@ -1310,7 +1315,7 @@ You have selected a datasource that is a SQL database. How would you like to spe
             data_asset_name = "custom_sql_query"
 
         elif single_or_multiple_data_asset_selection == "3":  # list it all
-            msg_prompt_warning: str = fr"""Warning: If you have a large number of tables in your datasource, this may take a very long time.
+            msg_prompt_warning: str = r"""Warning: I you have a large number of tables in your datasource, this may take a very long time.
 Would you like to continue?"""
             confirmation = click.prompt(
                 msg_prompt_warning, type=click.Choice(["y", "n"]), show_choices=True
@@ -1364,11 +1369,16 @@ Would you like to continue?"""
     datasource = context.get_datasource(datasource_name)
 
     if datasource.engine.dialect.name.lower() == "bigquery":
+        # bigquery table needs to contain the project id if it differs from the credentials project
+        if len(data_asset_name.split(".")) < 3:
+            project_id, _, _, _, _, _ = parse_bigquery_url(datasource.engine.url)
+            data_asset_name = f"{project_id}.{data_asset_name}"
+
         # bigquery also requires special handling
         bigquery_temp_table = click.prompt(
             "Great Expectations will create a table to use for "
             "validation." + os.linesep + "Please enter a name for this table: ",
-            default="SOME_PROJECT.SOME_DATASET.ge_tmp_" + str(uuid.uuid4())[:8],
+            default=f"SOME_PROJECT.SOME_DATASET.ge_tmp_{str(uuid.uuid4())[:8]}",
         )
         temp_table_kwargs = {
             "bigquery_temp_table": bigquery_temp_table,
@@ -1441,11 +1451,17 @@ def _verify_snowflake_dependent_modules() -> bool:
 
 
 def _verify_bigquery_dependent_modules() -> bool:
-    return verify_library_dependent_modules(
+    pybigquery_ok = verify_library_dependent_modules(
         python_import_name="pybigquery.sqlalchemy_bigquery",
         pip_library_name="pybigquery",
         module_names_to_reload=CLI_ONLY_SQLALCHEMY_ORDERED_DEPENDENCY_MODULE_NAMES,
     )
+    sqlalchemy_bigquery_ok = verify_library_dependent_modules(
+        python_import_name="sqlalchemy_bigquery",
+        pip_library_name="sqlalchemy_bigquery",
+        module_names_to_reload=CLI_ONLY_SQLALCHEMY_ORDERED_DEPENDENCY_MODULE_NAMES,
+    )
+    return pybigquery_ok or sqlalchemy_bigquery_ok
 
 
 def _verify_pyspark_dependent_modules() -> bool:
@@ -1620,7 +1636,7 @@ Great Expectations is building Data Docs from the data you just profiled!"""
                 cli_message(msg_skipping)
                 return
             else:
-                raise ValueError("Unrecognized option: " + option_selection)
+                raise ValueError(f"Unrecognized option: {option_selection}")
 
             # after getting the arguments from the user, let's try to run profiling again
             # (no dry run this time)
