@@ -5,14 +5,22 @@ from typing import Any, Callable, Dict, Optional, Set, Union
 
 import great_expectations.exceptions as ge_exceptions
 from great_expectations.core.id_dict import BatchKwargs, BatchSpec, IDDict
-from great_expectations.core.util import convert_to_json_serializable, safe_deep_copy
+from great_expectations.core.util import convert_to_json_serializable
 from great_expectations.exceptions import InvalidBatchIdError
-from great_expectations.types import SerializableDictDot
+from great_expectations.types import SerializableDictDot, safe_deep_copy
 from great_expectations.util import deep_filter_properties_iterable
 from great_expectations.validator.metric_configuration import MetricConfiguration
 
 logger = logging.getLogger(__name__)
 
+try:
+    import pyspark
+except ImportError:
+    pyspark = None
+    logger.debug(
+        "Unable to load pyspark; install optional spark dependency if you will be working with Spark dataframes"
+    )
+
 
 class BatchDefinition(SerializableDictDot):
     def __init__(
@@ -158,8 +166,6 @@ class BatchRequestBase(SerializableDictDot):
     validation (described above plus additional attribute validation) so as to formally validate user specified fields.
     """
 
-    field_names: Set[str] = set()
-
     def __init__(
         self,
         datasource_name: str,
@@ -181,22 +187,6 @@ class BatchRequestBase(SerializableDictDot):
         self._batch_identifiers = batch_identifiers
         self._batch_spec_passthrough = batch_spec_passthrough
 
-    @property
-    def runtime_parameters(self) -> dict:
-        return self._runtime_parameters
-
-    @runtime_parameters.setter
-    def runtime_parameters(self, value: dict):
-        self._runtime_parameters = value
-
-    @property
-    def batch_identifiers(self) -> dict:
-        return self._batch_identifiers
-
-    @batch_identifiers.setter
-    def batch_identifiers(self, value: dict):
-        self._batch_identifiers = value
-
     @property
     def datasource_name(self) -> str:
         return self._datasource_name
@@ -237,6 +227,22 @@ class BatchRequestBase(SerializableDictDot):
     def limit(self, value: int):
         self._limit = value
 
+    @property
+    def runtime_parameters(self) -> dict:
+        return self._runtime_parameters
+
+    @runtime_parameters.setter
+    def runtime_parameters(self, value: dict):
+        self._runtime_parameters = value
+
+    @property
+    def batch_identifiers(self) -> dict:
+        return self._batch_identifiers
+
+    @batch_identifiers.setter
+    def batch_identifiers(self, value: dict):
+        self._batch_identifiers = value
+
     @property
     def batch_spec_passthrough(self) -> dict:
         return self._batch_spec_passthrough
@@ -250,42 +256,44 @@ class BatchRequestBase(SerializableDictDot):
         return IDDict(self.to_json_dict()).to_id()
 
     def to_dict(self) -> dict:
-        dict_obj: dict = {}
-
-        field_name: str
-        field_value: Any
-        for field_name in self.field_names:
-            if hasattr(self, f"_{field_name}"):
-                field_value = getattr(self, field_name)
-                dict_obj[field_name] = field_value
-
-        dict_obj = standardize_batch_request_display_ordering(batch_request=dict_obj)
-
-        return dict_obj
+        return standardize_batch_request_display_ordering(
+            batch_request=super().to_dict()
+        )
 
     def to_json_dict(self) -> dict:
-        dict_obj: dict = self.to_dict()
-        serializeable_dict: dict = convert_to_json_serializable(data=dict_obj)
+        """
+        # TODO: <Alex>2/4/2022</Alex>
+        This implementation of "SerializableDictDot.to_json_dict() occurs frequently and should ideally serve as the
+        reference implementation in the "SerializableDictDot" class itself.  However, the circular import dependencies,
+        due to the location of the "great_expectations/types/__init__.py" and "great_expectations/core/util.py" modules
+        make this refactoring infeasible at the present time.
+        """
+
+        # if batch_data appears in BatchRequest, temporarily replace it with
+        # str placeholder before calling convert_to_json_serializable so that
+        # batch_data is not serialized
+        if batch_request_contains_batch_data(batch_request=self):
+            batch_data: Union[
+                BatchRequest, RuntimeBatchRequest, dict
+            ] = self.runtime_parameters["batch_data"]
+            self.runtime_parameters["batch_data"]: str = str(type(batch_data))
+            serializeable_dict: dict = convert_to_json_serializable(data=self.to_dict())
+            # after getting serializable_dict, restore original batch_data
+            self.runtime_parameters["batch_data"]: Union[
+                BatchRequest, RuntimeBatchRequest, dict
+            ] = batch_data
+        else:
+            serializeable_dict: dict = convert_to_json_serializable(data=self.to_dict())
+
         return serializeable_dict
 
-    def __repr__(self) -> str:
-        json_dict: dict = self.to_json_dict()
-        deep_filter_properties_iterable(
-            properties=json_dict,
-            keep_falsy_numerics=True,
-            inplace=True,
-        )
-        return json.dumps(json_dict, indent=2)
-
-    def __str__(self) -> str:
-        return self.__repr__()
-
     def __deepcopy__(self, memo):
         cls = self.__class__
         result = cls.__new__(cls)
 
         memo[id(self)] = result
-        for key, value in self.to_dict().items():
+
+        for key, value in self.to_raw_dict().items():
             value_copy = safe_deep_copy(data=value, memo=memo)
             setattr(result, key, value_copy)
 
@@ -295,8 +303,34 @@ class BatchRequestBase(SerializableDictDot):
         if not isinstance(other, self.__class__):
             # Delegate comparison to the other instance's __eq__.
             return NotImplemented
+
         return self.id == other.id
 
+    def __repr__(self) -> str:
+        """
+        # TODO: <Alex>2/4/2022</Alex>
+        This implementation of a custom "__repr__()" occurs frequently and should ideally serve as the reference
+        implementation in the "SerializableDictDot" class.  However, the circular import dependencies, due to the
+        location of the "great_expectations/types/__init__.py" and "great_expectations/core/util.py" modules make this
+        refactoring infeasible at the present time.
+        """
+        json_dict: dict = self.to_json_dict()
+        deep_filter_properties_iterable(
+            properties=json_dict,
+            inplace=True,
+        )
+        return json.dumps(json_dict, indent=2)
+
+    def __str__(self) -> str:
+        """
+        # TODO: <Alex>2/4/2022</Alex>
+        This implementation of a custom "__str__()" occurs frequently and should ideally serve as the reference
+        implementation in the "SerializableDictDot" class.  However, the circular import dependencies, due to the
+        location of the "great_expectations/types/__init__.py" and "great_expectations/core/util.py" modules make this
+        refactoring infeasible at the present time.
+        """
+        return self.__repr__()
+
     @staticmethod
     def _validate_init_parameters(
         datasource_name: str,
@@ -345,7 +379,7 @@ class BatchRequest(BatchRequestBase):
     limit: refers to the number of batches requested (not rows per batch)
     """
 
-    field_names: Set[str] = {
+    include_field_names: Set[str] = {
         "datasource_name",
         "data_connector_name",
         "data_asset_name",
@@ -381,7 +415,7 @@ class BatchRequest(BatchRequestBase):
 
 
 class RuntimeBatchRequest(BatchRequestBase):
-    field_names: Set[str] = {
+    include_field_names: Set[str] = {
         "datasource_name",
         "data_connector_name",
         "data_asset_name",
@@ -567,7 +601,6 @@ class Batch(SerializableDictDot):
         json_dict: dict = self.to_dict()
         deep_filter_properties_iterable(
             properties=json_dict["batch_request"],
-            keep_falsy_numerics=True,
             inplace=True,
         )
         return json_dict
@@ -595,6 +628,55 @@ class Batch(SerializableDictDot):
         return self._data.execution_engine.resolve_metrics((metric,))[metric.id]
 
 
+def materialize_batch_request(
+    batch_request: Optional[Union[BatchRequest, RuntimeBatchRequest, dict]] = None
+) -> Optional[Union[BatchRequest, RuntimeBatchRequest]]:
+    effective_batch_request: dict = get_batch_request_as_dict(
+        batch_request=batch_request
+    )
+
+    if not effective_batch_request:
+        return None
+
+    batch_request_class: type
+    if batch_request_contains_runtime_parameters(batch_request=effective_batch_request):
+        batch_request_class = RuntimeBatchRequest
+    else:
+        batch_request_class = BatchRequest
+
+    return batch_request_class(**effective_batch_request)
+
+
+def batch_request_contains_batch_data(
+    batch_request: Optional[Union[BatchRequest, RuntimeBatchRequest, dict]] = None
+) -> bool:
+    return (
+        batch_request_contains_runtime_parameters(batch_request=batch_request)
+        and batch_request["runtime_parameters"].get("batch_data") is not None
+    )
+
+
+def batch_request_contains_runtime_parameters(
+    batch_request: Optional[Union[BatchRequest, RuntimeBatchRequest, dict]] = None
+) -> bool:
+    return (
+        batch_request is not None
+        and batch_request.get("runtime_parameters") is not None
+    )
+
+
+def get_batch_request_as_dict(
+    batch_request: Optional[Union[BatchRequest, RuntimeBatchRequest, dict]] = None
+) -> Optional[dict]:
+    if batch_request is None:
+        return None
+
+    if isinstance(batch_request, (BatchRequest, RuntimeBatchRequest)):
+        batch_request = batch_request.to_dict()
+
+    return batch_request
+
+
 def get_batch_request_from_acceptable_arguments(
     datasource_name: Optional[str] = None,
     data_connector_name: Optional[str] = None,
@@ -778,7 +860,6 @@ def get_batch_request_from_acceptable_arguments(
 
     deep_filter_properties_iterable(
         properties=batch_request_as_dict,
-        keep_falsy_numerics=True,
         inplace=True,
     )
 
