@@ -1,12 +1,6 @@
 from typing import Optional
 
 from great_expectations.core.usage_statistics.anonymizers.anonymizer import Anonymizer
-from great_expectations.core.usage_statistics.anonymizers.data_connector_anonymizer import (
-    DataConnectorAnonymizer,
-)
-from great_expectations.core.usage_statistics.anonymizers.execution_engine_anonymizer import (
-    ExecutionEngineAnonymizer,
-)
 from great_expectations.datasource import (
     BaseDatasource,
     Datasource,
@@ -37,37 +31,32 @@ class DatasourceAnonymizer(Anonymizer):
             BaseDatasource,
         ]
 
-        self._execution_engine_anonymizer = ExecutionEngineAnonymizer(salt=salt)
-        self._data_connector_anonymizer = DataConnectorAnonymizer(salt=salt)
-
     def anonymize_datasource_info(self, name, config):
         anonymized_info_dict = {}
         anonymized_info_dict["anonymized_name"] = self.anonymize(name)
 
         # Legacy Datasources (<= v0.12 v2 BatchKwargs API)
-        if self.is_parent_class_recognized_v2_api(config=config) is not None:
-            self.anonymize_object_info(
+        if self.get_parent_class_v2_api(config=config) is not None:
+            self._anonymize_object_info(
                 anonymized_info_dict=anonymized_info_dict,
-                ge_classes=self._legacy_ge_classes,
                 object_config=config,
             )
         # Datasources (>= v0.13 v3 BatchRequest API), and custom v2 BatchKwargs API
-        elif self.is_parent_class_recognized_v3_api(config=config) is not None:
-            self.anonymize_object_info(
+        elif self.get_parent_class_v3_api(config=config) is not None:
+            self._anonymize_object_info(
                 anonymized_info_dict=anonymized_info_dict,
-                ge_classes=self._ge_classes,
                 object_config=config,
             )
             execution_engine_config = config.get("execution_engine")
             anonymized_info_dict[
                 "anonymized_execution_engine"
-            ] = self._execution_engine_anonymizer.anonymize_execution_engine_info(
+            ] = self._anonymize_execution_engine_info(
                 name=execution_engine_config.get("name", ""),
                 config=execution_engine_config,
             )
             data_connector_configs = config.get("data_connectors")
             anonymized_info_dict["anonymized_data_connectors"] = [
-                self._data_connector_anonymizer.anonymize_data_connector_info(
+                self.anonymize_data_connector_info(
                     name=data_connector_name, config=data_connector_config
                 )
                 for data_connector_name, data_connector_config in data_connector_configs.items()
@@ -83,9 +72,8 @@ class DatasourceAnonymizer(Anonymizer):
         anonymized_info_dict["anonymized_name"] = self.anonymize(name)
         if config.get("module_name") is None:
             config["module_name"] = "great_expectations.datasource"
-        self.anonymize_object_info(
+        self._anonymize_object_info(
             anonymized_info_dict=anonymized_info_dict,
-            ge_classes=self._ge_classes,
             object_config=config,
         )
 
@@ -113,7 +101,7 @@ class DatasourceAnonymizer(Anonymizer):
                         "module_name"
                     ] = "great_expectations.datasource.data_connector"
                 introspection_data_connector_anonymized_configs.append(
-                    self._data_connector_anonymizer.anonymize_data_connector_info(
+                    self.anonymize_data_connector_info(
                         name=data_connector_name, config=data_connector_config
                     )
                 )
@@ -133,7 +121,7 @@ class DatasourceAnonymizer(Anonymizer):
                         "module_name"
                     ] = "great_expectations.datasource.data_connector"
                 tables_data_connector_anonymized_configs.append(
-                    self._data_connector_anonymizer.anonymize_data_connector_info(
+                    self.anonymize_data_connector_info(
                         name=data_connector_name, config=data_connector_config
                     )
                 )
@@ -145,20 +133,20 @@ class DatasourceAnonymizer(Anonymizer):
 
         return anonymized_info_dict
 
-    def is_parent_class_recognized(self, config) -> Optional[str]:
-        return self._is_parent_class_recognized(
+    def get_parent_class(self, config) -> Optional[str]:
+        return super().get_parent_class(
             classes_to_check=self._ge_classes + self._legacy_ge_classes,
             object_config=config,
         )
 
-    def is_parent_class_recognized_v2_api(self, config) -> Optional[str]:
-        return self._is_parent_class_recognized(
+    def get_parent_class_v2_api(self, config) -> Optional[str]:
+        return super().get_parent_class(
             classes_to_check=self._legacy_ge_classes,
             object_config=config,
         )
 
-    def is_parent_class_recognized_v3_api(self, config) -> Optional[str]:
-        return self._is_parent_class_recognized(
+    def get_parent_class_v3_api(self, config) -> Optional[str]:
+        return super().get_parent_class(
             classes_to_check=self._ge_classes,
             object_config=config,
         )
