@@ -60,6 +60,15 @@ class GeCloudStoreBackend(StoreBackend, metaclass=ABCMeta):
         self._ge_cloud_resource_type = ge_cloud_resource_type or singularize(
             ge_cloud_resource_name
         )
+
+        # TOTO: remove when account_id is deprecated
+        if ge_cloud_credentials.get("account_id"):
+            logger.warning(
+                'The "account_id" ge_cloud_credentials key has been renamed to "organization_id" and will '
+                "be deprecated in the next major release."
+            )
+            ge_cloud_credentials["organization_id"] = ge_cloud_credentials["account_id"]
+            ge_cloud_credentials.pop("account_id")
         self._ge_cloud_credentials = ge_cloud_credentials
 
         # Initialize with store_backend_id if not part of an HTMLSiteStore
@@ -106,8 +115,7 @@ class GeCloudStoreBackend(StoreBackend, metaclass=ABCMeta):
 
     def _update(self, ge_cloud_id, value, **kwargs):
         resource_type = self.ge_cloud_resource_type
-        account_id = self.ge_cloud_credentials["account_id"]
-
+        organization_id = self.ge_cloud_credentials["organization_id"]
         attributes_key = self.PAYLOAD_ATTRIBUTES_KEYS[resource_type]
 
         data = {
@@ -116,15 +124,15 @@ class GeCloudStoreBackend(StoreBackend, metaclass=ABCMeta):
                 "id": ge_cloud_id,
                 "attributes": {
                     attributes_key: value,
-                    "account_id": account_id,
+                    "organization_id": organization_id,
                 },
             }
         }
 
         url = urljoin(
             self.ge_cloud_base_url,
-            f"accounts/"
-            f"{account_id}/"
+            f"organizations/"
+            f"{organization_id}/"
             f"{hyphen(self.ge_cloud_resource_name)}/"
             f"{ge_cloud_id}",
         )
@@ -167,7 +175,7 @@ class GeCloudStoreBackend(StoreBackend, metaclass=ABCMeta):
 
         resource_type = self.ge_cloud_resource_type
         resource_name = self.ge_cloud_resource_name
-        account_id = self.ge_cloud_credentials["account_id"]
+        organization_id = self.ge_cloud_credentials["organization_id"]
 
         attributes_key = self.PAYLOAD_ATTRIBUTES_KEYS[resource_type]
 
@@ -175,7 +183,7 @@ class GeCloudStoreBackend(StoreBackend, metaclass=ABCMeta):
             "data": {
                 "type": resource_type,
                 "attributes": {
-                    "account_id": account_id,
+                    "organization_id": organization_id,
                     attributes_key: value,
                     **(kwargs if self.validate_set_kwargs(kwargs) else {}),
                 },
@@ -184,7 +192,7 @@ class GeCloudStoreBackend(StoreBackend, metaclass=ABCMeta):
 
         url = urljoin(
             self.ge_cloud_base_url,
-            f"accounts/" f"{account_id}/" f"{hyphen(resource_name)}",
+            f"organizations/" f"{organization_id}/" f"{hyphen(resource_name)}",
         )
         try:
             response = requests.post(url, json=data, headers=self.auth_headers)
@@ -221,8 +229,8 @@ class GeCloudStoreBackend(StoreBackend, metaclass=ABCMeta):
     def list_keys(self):
         url = urljoin(
             self.ge_cloud_base_url,
-            f"accounts/"
-            f"{self.ge_cloud_credentials['account_id']}/"
+            f"organizations/"
+            f"{self.ge_cloud_credentials['organization_id']}/"
             f"{hyphen(self.ge_cloud_resource_name)}",
         )
         try:
@@ -244,7 +252,7 @@ class GeCloudStoreBackend(StoreBackend, metaclass=ABCMeta):
         ge_cloud_id = key[1]
         url = urljoin(
             self.ge_cloud_base_url,
-            f"accounts/{self.ge_cloud_credentials['account_id']}/{hyphen(self.ge_cloud_resource_name)}/{ge_cloud_id}",
+            f"organizations/{self.ge_cloud_credentials['organization_id']}/{hyphen(self.ge_cloud_resource_name)}/{ge_cloud_id}",
         )
         return url
 
@@ -266,8 +274,8 @@ class GeCloudStoreBackend(StoreBackend, metaclass=ABCMeta):
 
         url = urljoin(
             self.ge_cloud_base_url,
-            f"accounts/"
-            f"{self.ge_cloud_credentials['account_id']}/"
+            f"organizations/"
+            f"{self.ge_cloud_credentials['organization_id']}/"
             f"{hyphen(self.ge_cloud_resource_name)}/"
             f"{ge_cloud_id}",
         )
