@@ -115,7 +115,7 @@ class TupleStoreBackend(StoreBackend, metaclass=ABCMeta):
             converted_string = "/".join(key)
 
         if self.filepath_prefix:
-            converted_string = self.filepath_prefix + "/" + converted_string
+            converted_string = f"{self.filepath_prefix}/{converted_string}"
         if self.filepath_suffix:
             converted_string += self.filepath_suffix
         if self.platform_specific_separator:
@@ -165,9 +165,7 @@ class TupleStoreBackend(StoreBackend, metaclass=ABCMeta):
             # Convert the template to a regex
             indexed_string_substitutions = re.findall(r"{\d+}", filepath_template)
             tuple_index_list = [
-                "(?P<tuple_index_{}>.*)".format(
-                    i,
-                )
+                f"(?P<tuple_index_{i}>.*)"
                 for i in range(len(indexed_string_substitutions))
             ]
             intermediate_filepath_regex = re.sub(
@@ -186,7 +184,7 @@ class TupleStoreBackend(StoreBackend, metaclass=ABCMeta):
                 tuple_index = int(
                     re.search(r"\d+", indexed_string_substitutions[i]).group(0)
                 )
-                key_element = matches.group("tuple_index_" + str(i))
+                key_element = matches.group(f"tuple_index_{str(i)}")
                 new_key[tuple_index] = key_element
 
             new_key = tuple(new_key)
@@ -407,13 +405,13 @@ class TupleFilesystemStoreBackend(TupleStoreBackend):
 
         if protocol is None:
             protocol = "file:"
-        url = protocol + "//" + full_path
+        url = f"{protocol}//{full_path}"
         return url
 
     def get_public_url_for_key(self, key, protocol=None):
         if not self.base_public_path:
             raise StoreBackendError(
-                f"""Error: No base_public_path was configured!
+                """Error: No base_public_path was configured!
                     - A public URL was requested base_public_path was not configured for the TupleFilesystemStoreBackend
                 """
             )
@@ -633,7 +631,7 @@ class TupleS3StoreBackend(TupleStoreBackend):
                     if s3_object_key.startswith("/"):
                         s3_object_key = s3_object_key[1:]
                 else:
-                    if s3_object_key.startswith(self.prefix + "/"):
+                    if s3_object_key.startswith(f"{self.prefix}/"):
                         s3_object_key = s3_object_key[len(self.prefix) + 1 :]
             if self.filepath_prefix and not s3_object_key.startswith(
                 self.filepath_prefix
@@ -658,7 +656,7 @@ class TupleS3StoreBackend(TupleStoreBackend):
         elif location is None:
             location = "https://s3.amazonaws.com"
         else:
-            location = "https://s3-" + location + ".amazonaws.com"
+            location = f"https://s3-{location}.amazonaws.com"
 
         s3_key = self._convert_key_to_filepath(key)
 
@@ -669,14 +667,14 @@ class TupleS3StoreBackend(TupleStoreBackend):
     def get_public_url_for_key(self, key, protocol=None):
         if not self.base_public_path:
             raise StoreBackendError(
-                f"""Error: No base_public_path was configured!
+                """Error: No base_public_path was configured!
                     - A public URL was requested base_public_path was not configured for the
                 """
             )
         s3_key = self._convert_key_to_filepath(key)
         # <WILL> What happens if there is a prefix?
         if self.base_public_path[-1] != "/":
-            public_url = self.base_public_path + "/" + s3_key
+            public_url = f"{self.base_public_path}/{s3_key}"
         else:
             public_url = self.base_public_path + s3_key
         return public_url
@@ -912,7 +910,7 @@ class TupleGCSStoreBackend(TupleStoreBackend):
     def get_public_url_for_key(self, key, protocol=None):
         if not self.base_public_path:
             raise StoreBackendError(
-                f"""Error: No base_public_path was configured!
+                """Error: No base_public_path was configured!
                     - A public URL was requested base_public_path was not configured for the
                 """
             )
@@ -927,7 +925,7 @@ class TupleGCSStoreBackend(TupleStoreBackend):
         else:
             if self.base_public_path:
                 if self.base_public_path[-1] != "/":
-                    path_url = "/" + path
+                    path_url = f"/{path}"
                 else:
                     path_url = path
             else:
@@ -1053,7 +1051,7 @@ class TupleAzureBlobStoreBackend(TupleStoreBackend):
             name_starts_with=self.prefix
         ):
             az_blob_key = os.path.relpath(obj.name)
-            if az_blob_key.startswith(self.prefix + "/"):
+            if az_blob_key.startswith(f"{self.prefix}/"):
                 az_blob_key = az_blob_key[len(self.prefix) + 1 :]
             if self.filepath_prefix and not az_blob_key.startswith(
                 self.filepath_prefix
@@ -1099,7 +1097,7 @@ class TupleAzureBlobStoreBackend(TupleStoreBackend):
         if copy_properties.status != "success":
             dest_blob.abort_copy(copy_properties.id)
             raise StoreBackendError(
-                f"Unable to copy blob %s with status %s"
+                "Unable to copy blob %s with status %s"
                 % (source_blob_path, copy_properties.status)
             )
         source_blob.delete_blob()
