@@ -33,12 +33,7 @@ except ImportError:
 import pyparsing as pp
 
 import great_expectations.exceptions as ge_exceptions
-from great_expectations.data_context.types.base import (
-    CheckpointConfig,
-    CheckpointConfigSchema,
-    DataContextConfig,
-    DataContextConfigSchema,
-)
+from great_expectations.data_context.types.base import BaseYamlConfig
 from great_expectations.util import load_class, verify_dynamic_loading_support
 
 try:
@@ -455,13 +450,11 @@ def substitute_all_config_variables(
 
     :param data:
     :param replace_variables_dict:
+    :param dollar_sign_escape_string: a reserved character for specifying parameters
     :return: a dictionary with all the variables replaced with their values
     """
-    if isinstance(data, DataContextConfig):
-        data = DataContextConfigSchema().dump(data)
-
-    if isinstance(data, CheckpointConfig):
-        data = CheckpointConfigSchema().dump(data)
+    if isinstance(data, BaseYamlConfig):
+        data = (data.__class__.get_schema_class())().dump(data)
 
     if isinstance(data, dict) or isinstance(data, OrderedDict):
         return {
