@@ -17,19 +17,19 @@ from great_expectations.core.util import (
 )
 from great_expectations.data_asset import DataAsset
 from great_expectations.data_asset.util import DocInherit, parse_result_format
+from great_expectations.dataset.dataset import Dataset
+from great_expectations.dataset.pandas_dataset import PandasDataset
 from great_expectations.dataset.util import (
     check_sql_engine_dialect,
     get_approximate_percentile_disc_sql,
 )
 from great_expectations.util import (
     generate_temporary_table_name,
+    get_pyathena_potential_type,
     get_sqlalchemy_inspector,
     import_library_module,
 )
 
-from .dataset import Dataset
-from .pandas_dataset import PandasDataset
-
 logger = logging.getLogger(__name__)
 
 try:
@@ -101,39 +101,48 @@ try:
 except (ImportError, KeyError, AttributeError):
     snowflake = None
 
+_BIGQUERY_MODULE_NAME = "sqlalchemy_bigquery"
 try:
-    import pybigquery.sqlalchemy_bigquery
+    import sqlalchemy_bigquery as sqla_bigquery
 
-    ###
-    # NOTE: 20210816 - jdimatteo: A convention we rely on is for SqlAlchemy dialects
-    # to define an attribute "dialect". A PR has been submitted to fix this upstream
-    # with https://github.com/googleapis/python-bigquery-sqlalchemy/pull/251. If that
-    # fix isn't present, add this "dialect" attribute here:
-    if not hasattr(pybigquery.sqlalchemy_bigquery, "dialect"):
-        pybigquery.sqlalchemy_bigquery.dialect = (
-            pybigquery.sqlalchemy_bigquery.BigQueryDialect
-        )
-
-    # Sometimes "pybigquery.sqlalchemy_bigquery" fails to self-register in certain environments, so we do it explicitly.
-    # (see https://stackoverflow.com/questions/53284762/nosuchmoduleerror-cant-load-plugin-sqlalchemy-dialectssnowflake)
-    registry.register("bigquery", "pybigquery.sqlalchemy_bigquery", "BigQueryDialect")
-    try:
-        getattr(pybigquery.sqlalchemy_bigquery, "INTEGER")
-        bigquery_types_tuple = None
-    except AttributeError:
-        # In older versions of the pybigquery driver, types were not exported, so we use a hack
-        logger.warning(
-            "Old pybigquery driver version detected. Consider upgrading to 0.4.14 or later."
-        )
-        from collections import namedtuple
-
-        BigQueryTypes = namedtuple(
-            "BigQueryTypes", sorted(pybigquery.sqlalchemy_bigquery._type_map)
-        )
-        bigquery_types_tuple = BigQueryTypes(**pybigquery.sqlalchemy_bigquery._type_map)
-except (ImportError, AttributeError):
+    registry.register("bigquery", _BIGQUERY_MODULE_NAME, "BigQueryDialect")
     bigquery_types_tuple = None
-    pybigquery = None
+except ImportError:
+    try:
+        import pybigquery.sqlalchemy_bigquery as sqla_bigquery
+
+        warnings.warn(
+            "The pybigquery package is obsolete, please use sqlalchemy-bigquery",
+            DeprecationWarning,
+        )
+        _BIGQUERY_MODULE_NAME = "pybigquery.sqlalchemy_bigquery"
+        ###
+        # NOTE: 20210816 - jdimatteo: A convention we rely on is for SqlAlchemy dialects
+        # to define an attribute "dialect". A PR has been submitted to fix this upstream
+        # with https://github.com/googleapis/python-bigquery-sqlalchemy/pull/251. If that
+        # fix isn't present, add this "dialect" attribute here:
+        if not hasattr(sqla_bigquery, "dialect"):
+            sqla_bigquery.dialect = sqla_bigquery.BigQueryDialect
+
+        # Sometimes "pybigquery.sqlalchemy_bigquery" fails to self-register in certain environments, so we do it explicitly.
+        # (see https://stackoverflow.com/questions/53284762/nosuchmoduleerror-cant-load-plugin-sqlalchemy-dialectssnowflake)
+        registry.register("bigquery", _BIGQUERY_MODULE_NAME, "BigQueryDialect")
+        try:
+            getattr(sqla_bigquery, "INTEGER")
+            bigquery_types_tuple = None
+        except AttributeError:
+            # In older versions of the pybigquery driver, types were not exported, so we use a hack
+            logger.warning(
+                "Old pybigquery driver version detected. Consider upgrading to 0.4.14 or later."
+            )
+            from collections import namedtuple
+
+            BigQueryTypes = namedtuple("BigQueryTypes", sorted(sqla_bigquery._type_map))
+            bigquery_types_tuple = BigQueryTypes(**sqla_bigquery._type_map)
+    except (ImportError, AttributeError):
+        sqla_bigquery = None
+        bigquery_types_tuple = None
+        pybigquery = None
 
 
 try:
@@ -578,11 +587,13 @@ class SqlAlchemyDataset(MetaSqlAlchemyDataset):
             "sqlite",
             "oracle",
             "mssql",
+            "hive",
         ]:
             # These are the officially included and supported dialects by sqlalchemy
             self.dialect = import_library_module(
-                module_name="sqlalchemy.dialects." + self.engine.dialect.name
+                module_name=f"sqlalchemy.dialects.{self.engine.dialect.name}"
             )
+
         elif dialect_name == "snowflake":
             self.dialect = import_library_module(
                 module_name="snowflake.sqlalchemy.snowdialect"
@@ -597,9 +608,7 @@ class SqlAlchemyDataset(MetaSqlAlchemyDataset):
                 module_name="sqlalchemy_redshift.dialect"
             )
         elif dialect_name == "bigquery":
-            self.dialect = import_library_module(
-                module_name="pybigquery.sqlalchemy_bigquery"
-            )
+            self.dialect = import_library_module(module_name=_BIGQUERY_MODULE_NAME)
         elif dialect_name == "awsathena":
             self.dialect = import_library_module(
                 module_name="pyathena.sqlalchemy_athena"
@@ -642,17 +651,9 @@ class SqlAlchemyDataset(MetaSqlAlchemyDataset):
 
             if self.generated_table_name is not None:
                 if self.engine.dialect.name.lower() == "bigquery":
-                    logger.warning(
-                        "Created permanent table {table_name}".format(
-                            table_name=table_name
-                        )
-                    )
+                    logger.warning(f"Created permanent table {table_name}")
                 if self.engine.dialect.name.lower() == "awsathena":
-                    logger.warning(
-                        "Created permanent table default.{table_name}".format(
-                            table_name=table_name
-                        )
-                    )
+                    logger.warning(f"Created permanent table default.{table_name}")
 
         try:
             insp = get_sqlalchemy_inspector(self.engine)
@@ -706,30 +707,24 @@ class SqlAlchemyDataset(MetaSqlAlchemyDataset):
             # If it fails, we are trying to get the data using read_sql
             head_sql_str = "select * from "
             if self._table.schema and self.engine.dialect.name.lower() != "bigquery":
-                head_sql_str += self._table.schema + "." + self._table.name
+                head_sql_str += f"{self._table.schema}.{self._table.name}"
             elif self.engine.dialect.name.lower() == "bigquery":
-                head_sql_str += "`" + self._table.name + "`"
+                head_sql_str += f"`{self._table.name}`"
             else:
                 head_sql_str += self._table.name
             head_sql_str += f" limit {n:d}"
 
             # Limit is unknown in mssql! Use top instead!
             if self.engine.dialect.name.lower() == "mssql":
-                head_sql_str = "select top({n}) * from {table}".format(
-                    n=n, table=self._table.name
-                )
+                head_sql_str = f"select top({n}) * from {self._table.name}"
 
             # Limit doesn't work in oracle either
             if self.engine.dialect.name.lower() == "oracle":
-                head_sql_str = "select * from {table} WHERE ROWNUM <= {n}".format(
-                    table=self._table.name, n=n
-                )
+                head_sql_str = f"select * from {self._table.name} WHERE ROWNUM <= {n}"
 
             # Limit is unknown in teradatasql! Use sample instead!
             if self.engine.dialect.name.lower() == "teradatasql":
-                head_sql_str = "select * from {table} sample {n}".format(
-                    table=self._table.name, n=n
-                )
+                head_sql_str = f"select * from {self._table.name} sample {n}"
 
             df = pd.read_sql(head_sql_str, con=self.engine)
         except StopIteration:
@@ -1200,7 +1195,7 @@ class SqlAlchemyDataset(MetaSqlAlchemyDataset):
             case_conditions.append(
                 sa.func.sum(
                     sa.case([(sa.column(column) < bins[idx + 1], 1)], else_=0)
-                ).label("bin_" + str(idx))
+                ).label(f"bin_{str(idx)}")
             )
             idx += 1
 
@@ -1219,7 +1214,7 @@ class SqlAlchemyDataset(MetaSqlAlchemyDataset):
                         ],
                         else_=0,
                     )
-                ).label("bin_" + str(idx))
+                ).label(f"bin_{str(idx)}")
             )
 
         if (
@@ -1236,7 +1231,7 @@ class SqlAlchemyDataset(MetaSqlAlchemyDataset):
             case_conditions.append(
                 sa.func.sum(
                     sa.case([(sa.column(column) >= bins[-2], 1)], else_=0)
-                ).label("bin_" + str(len(bins) - 1))
+                ).label(f"bin_{str(len(bins) - 1)}")
             )
         else:
             case_conditions.append(
@@ -1253,7 +1248,7 @@ class SqlAlchemyDataset(MetaSqlAlchemyDataset):
                         ],
                         else_=0,
                     )
-                ).label("bin_" + str(len(bins) - 1))
+                ).label(f"bin_{str(len(bins) - 1)}")
             )
 
         query = (
@@ -1404,31 +1399,21 @@ class SqlAlchemyDataset(MetaSqlAlchemyDataset):
             engine_dialect = str(engine_dialect, "utf-8")
 
         if engine_dialect == "bigquery":
-            stmt = "CREATE OR REPLACE VIEW `{table_name}` AS {custom_sql}".format(
-                table_name=table_name, custom_sql=custom_sql
-            )
+            stmt = f"CREATE OR REPLACE VIEW `{table_name}` AS {custom_sql}"
         elif engine_dialect == "databricks":
-            stmt = "CREATE OR REPLACE VIEW `{table_name}` AS {custom_sql}".format(
-                table_name=table_name, custom_sql=custom_sql
-            )
+            stmt = f"CREATE OR REPLACE VIEW `{table_name}` AS {custom_sql}"
         elif engine_dialect == "dremio":
-            stmt = "CREATE OR REPLACE VDS {table_name} AS {custom_sql}".format(
-                table_name=table_name, custom_sql=custom_sql
-            )
+            stmt = f"CREATE OR REPLACE VDS {table_name} AS {custom_sql}"
         elif engine_dialect == "snowflake":
             table_type = "TEMPORARY" if self.generated_table_name else "TRANSIENT"
 
-            logger.info("Creating temporary table %s" % table_name)
+            logger.info(f"Creating temporary table {table_name}")
             if schema_name is not None:
-                table_name = schema_name + "." + table_name
-            stmt = "CREATE OR REPLACE {table_type} TABLE {table_name} AS {custom_sql}".format(
-                table_type=table_type, table_name=table_name, custom_sql=custom_sql
-            )
+                table_name = f"{schema_name}.{table_name}"
+            stmt = f"CREATE OR REPLACE {table_type} TABLE {table_name} AS {custom_sql}"
         elif self.sql_engine_dialect.name == "mysql":
             # Note: We can keep the "MySQL" clause separate for clarity, even though it is the same as the generic case.
-            stmt = "CREATE TEMPORARY TABLE {table_name} AS {custom_sql}".format(
-                table_name=table_name, custom_sql=custom_sql
-            )
+            stmt = f"CREATE TEMPORARY TABLE {table_name} AS {custom_sql}"
         elif self.sql_engine_dialect.name == "mssql":
             # Insert "into #{table_name}" in the custom sql query right before the "from" clause
             # Split is case sensitive so detect case.
@@ -1439,12 +1424,10 @@ class SqlAlchemyDataset(MetaSqlAlchemyDataset):
                 strsep = "FROM"
             custom_sqlmod = custom_sql.split(strsep, maxsplit=1)
             stmt = (
-                custom_sqlmod[0] + "into {table_name} from" + custom_sqlmod[1]
+                f"{custom_sqlmod[0]}into {{table_name}} from{custom_sqlmod[1]}"
             ).format(table_name=table_name)
         elif engine_dialect == "awsathena":
-            stmt = "CREATE TABLE {table_name} AS {custom_sql}".format(
-                table_name=table_name, custom_sql=custom_sql
-            )
+            stmt = f"CREATE TABLE {table_name} AS {custom_sql}"
         elif engine_dialect == "oracle":
             # oracle 18c introduced PRIVATE temp tables which are transient objects
             stmt_1 = "CREATE PRIVATE TEMPORARY TABLE {table_name} ON COMMIT PRESERVE DEFINITION AS {custom_sql}".format(
@@ -1459,10 +1442,14 @@ class SqlAlchemyDataset(MetaSqlAlchemyDataset):
             stmt = 'CREATE VOLATILE TABLE "{table_name}" AS ({custom_sql}) WITH DATA NO PRIMARY INDEX ON COMMIT PRESERVE ROWS'.format(
                 table_name=table_name, custom_sql=custom_sql
             )
-        else:
-            stmt = 'CREATE TEMPORARY TABLE "{table_name}" AS {custom_sql}'.format(
-                table_name=table_name, custom_sql=custom_sql
+        elif self.sql_engine_dialect.name.lower() in ("hive", b"hive"):
+            stmt = "CREATE TEMPORARY TABLE {schema_name}.{table_name} AS {custom_sql}".format(
+                schema_name=schema_name if schema_name is not None else "default",
+                table_name=table_name,
+                custom_sql=custom_sql,
             )
+        else:
+            stmt = f'CREATE TEMPORARY TABLE "{table_name}" AS {custom_sql}'
 
         if engine_dialect == "oracle":
             try:
@@ -1612,7 +1599,7 @@ WHERE
             pass
         else:
             raise ValueError(
-                "ignore_row_if was set to an unexpected value: %s" % ignore_row_if
+                f"ignore_row_if was set to an unexpected value: {ignore_row_if}"
             )
 
         unexpected_count = self.engine.execute(query).fetchone()
@@ -1694,7 +1681,7 @@ WHERE
             if (
                 isinstance(
                     self.sql_engine_dialect,
-                    pybigquery.sqlalchemy_bigquery.BigQueryDialect,
+                    sqla_bigquery.BigQueryDialect,
                 )
                 and bigquery_types_tuple is not None
             ):
@@ -1738,9 +1725,9 @@ WHERE
             col_data = [col for col in self.columns if col["name"] == column][0]
             col_type = type(col_data["type"])
         except IndexError:
-            raise ValueError("Unrecognized column: %s" % column)
+            raise ValueError(f"Unrecognized column: {column}")
         except KeyError:
-            raise ValueError("No database type data available for column: %s" % column)
+            raise ValueError(f"No database type data available for column: {column}")
 
         try:
             # Our goal is to be as explicit as possible. We will match the dialect
@@ -1757,19 +1744,22 @@ WHERE
                 success = True
             else:
                 type_module = self._get_dialect_type_module()
-                potential_type = getattr(type_module, type_)
-                # In the case of the PyAthena dialect we need to verify that
-                # the type returned is indeed a type and not an instance.
-                if not inspect.isclass(potential_type):
-                    real_type = type(potential_type)
+                if type_module.__name__ == "pyathena.sqlalchemy_athena":
+                    potential_type = get_pyathena_potential_type(type_module, type_)
+                    # In the case of the PyAthena dialect we need to verify that
+                    # the type returned is indeed a type and not an instance.
+                    if not inspect.isclass(potential_type):
+                        real_type = type(potential_type)
+                    else:
+                        real_type = potential_type
                 else:
-                    real_type = potential_type
+                    real_type = getattr(type_module, type_)
                 success = issubclass(col_type, real_type)
 
             return {"success": success, "result": {"observed_value": col_type.__name__}}
 
         except AttributeError:
-            raise ValueError("Type not recognized by current driver: %s" % type_)
+            raise ValueError(f"Type not recognized by current driver: {type_}")
 
     @DocInherit
     @DataAsset.expectation(["column", "type_list", "mostly"])
@@ -1792,9 +1782,9 @@ WHERE
             col_data = [col for col in self.columns if col["name"] == column][0]
             col_type = type(col_data["type"])
         except IndexError:
-            raise ValueError("Unrecognized column: %s" % column)
+            raise ValueError(f"Unrecognized column: {column}")
         except KeyError:
-            raise ValueError("No database type data available for column: %s" % column)
+            raise ValueError(f"No database type data available for column: {column}")
 
         # Our goal is to be as explicit as possible. We will match the dialect
         # if that is possible. If there is no dialect available, we *will*
@@ -1812,16 +1802,20 @@ WHERE
             type_module = self._get_dialect_type_module()
             for type_ in type_list:
                 try:
-                    potential_type = getattr(type_module, type_)
-                    # In the case of the PyAthena dialect we need to verify that
-                    # the type returned is indeed a type and not an instance.
-                    if not inspect.isclass(potential_type):
-                        type_class = type(potential_type)
+                    if type_module.__name__ == "pyathena.sqlalchemy_athena":
+                        potential_type = get_pyathena_potential_type(type_module, type_)
+                        # In the case of the PyAthena dialect we need to verify that
+                        # the type returned is indeed a type and not an instance.
+                        if not inspect.isclass(potential_type):
+                            real_type = type(potential_type)
+                        else:
+                            real_type = potential_type
+                        types.append(real_type)
                     else:
-                        type_class = potential_type
-                    types.append(type_class)
+                        potential_type = getattr(type_module, type_)
+                        types.append(potential_type)
                 except AttributeError:
-                    logger.debug("Unrecognized type: %s" % type_)
+                    logger.debug(f"Unrecognized type: {type_}")
             if len(types) == 0:
                 logger.warning(
                     "No recognized sqlalchemy types in type_list for current dialect."
@@ -2096,9 +2090,7 @@ WHERE
 
         try:
             # Bigquery
-            if isinstance(
-                self.sql_engine_dialect, pybigquery.sqlalchemy_bigquery.BigQueryDialect
-            ):
+            if isinstance(self.sql_engine_dialect, sqla_bigquery.BigQueryDialect):
                 if positive:
                     return sa.func.REGEXP_CONTAINS(sa.column(column), literal(regex))
                 else:
@@ -2181,7 +2173,7 @@ WHERE
         regex_expression = self._get_dialect_regex_expression(column, regex)
         if regex_expression is None:
             logger.warning(
-                "Regex is not supported for dialect %s" % str(self.sql_engine_dialect)
+                f"Regex is not supported for dialect {str(self.sql_engine_dialect)}"
             )
             raise NotImplementedError
 
@@ -2203,7 +2195,7 @@ WHERE
         )
         if regex_expression is None:
             logger.warning(
-                "Regex is not supported for dialect %s" % str(self.sql_engine_dialect)
+                f"Regex is not supported for dialect {str(self.sql_engine_dialect)}"
             )
             raise NotImplementedError
 
@@ -2231,7 +2223,7 @@ WHERE
         regex_expression = self._get_dialect_regex_expression(column, regex_list[0])
         if regex_expression is None:
             logger.warning(
-                "Regex is not supported for dialect %s" % str(self.sql_engine_dialect)
+                f"Regex is not supported for dialect {str(self.sql_engine_dialect)}"
             )
             raise NotImplementedError
 
@@ -2270,7 +2262,7 @@ WHERE
         )
         if regex_expression is None:
             logger.warning(
-                "Regex is not supported for dialect %s" % str(self.sql_engine_dialect)
+                f"Regex is not supported for dialect {str(self.sql_engine_dialect)}"
             )
             raise NotImplementedError
 
