@@ -340,13 +340,12 @@ class BatchKwargsGenerator:
             except StopIteration:
                 # This is a degenerate case in which no kwargs are actually being generated
                 logger.warning(
-                    "No batch_kwargs found for data_asset_name %s" % data_asset_name
+                    f"No batch_kwargs found for data_asset_name {data_asset_name}"
                 )
                 return {}
         except TypeError:
             # If we don't actually have an iterator we can generate, even after resetting, just return empty
             logger.warning(
-                "Unable to generate batch_kwargs for data_asset_name %s"
-                % data_asset_name
+                f"Unable to generate batch_kwargs for data_asset_name {data_asset_name}"
             )
             return {}
