@@ -18,7 +18,7 @@ logger = logging.getLogger(__name__)
 
 
 class S3GlobReaderBatchKwargsGenerator(BatchKwargsGenerator):
-    """
+    r"""
     S3 BatchKwargGenerator provides support for generating batches of data from an S3 bucket. For the S3 batch kwargs generator, assets must
     be individually defined using a prefix and glob, although several additional configuration parameters are available
     for assets (see below).
@@ -141,7 +141,7 @@ class S3GlobReaderBatchKwargsGenerator(BatchKwargsGenerator):
                 "limit": limit,
             }
             raise BatchKwargsError(
-                "Unknown asset_name %s" % data_asset_name, batch_kwargs
+                f"Unknown asset_name {data_asset_name}", batch_kwargs
             )
 
         if data_asset_name not in self._iterators:
@@ -180,7 +180,7 @@ class S3GlobReaderBatchKwargsGenerator(BatchKwargsGenerator):
                 asset_config = self._assets[data_asset_name]
             except KeyError:
                 raise GreatExpectationsError(
-                    "No asset config found for asset %s" % data_asset_name
+                    f"No asset config found for asset {data_asset_name}"
                 )
             if data_asset_name not in self._iterators:
                 self._iterators[data_asset_name] = {}
@@ -225,7 +225,7 @@ class S3GlobReaderBatchKwargsGenerator(BatchKwargsGenerator):
         limit=None,
     ):
         batch_kwargs = {
-            "s3": "s3a://" + self.bucket + "/" + key,
+            "s3": f"s3a://{self.bucket}/{key}",
             "reader_options": self.reader_options,
         }
         if asset_config.get("reader_options"):
@@ -260,7 +260,7 @@ class S3GlobReaderBatchKwargsGenerator(BatchKwargsGenerator):
             )
 
         logger.debug(
-            "Fetching objects from S3 with query options: %s" % str(query_options)
+            f"Fetching objects from S3 with query options: {str(query_options)}"
         )
         asset_options = self._s3.list_objects_v2(**query_options)
         if directory_assets:
@@ -301,14 +301,12 @@ class S3GlobReaderBatchKwargsGenerator(BatchKwargsGenerator):
                 keys,
             )
         ]
-        for key in keys:
-            yield key
+        yield from keys
 
         if asset_options["IsTruncated"]:
             iterator_dict["continuation_token"] = asset_options["NextContinuationToken"]
             # Recursively fetch more
-            for key in self._get_asset_options(asset_config, iterator_dict):
-                yield key
+            yield from self._get_asset_options(asset_config, iterator_dict)
         elif "continuation_token" in iterator_dict:
             # Make sure we clear the token once we've gotten fully through
             del iterator_dict["continuation_token"]
@@ -360,7 +358,7 @@ class S3GlobReaderBatchKwargsGenerator(BatchKwargsGenerator):
             # In the case that there is a defined regex, the user *wanted* a partition. But it didn't match.
             # So, we'll add a *sortable* id
             if matches is None:
-                logger.warning("No match found for key: %s" % key)
+                logger.warning(f"No match found for key: {key}")
                 return (
                     datetime.datetime.now(datetime.timezone.utc).strftime(
                         "%Y%m%dT%H%M%S.%fZ"
