@@ -1,6 +1,9 @@
 import copy
 import logging
 
+from great_expectations.datasource.data_connector.configured_asset_sql_data_connector import (
+    ConfiguredAssetSqlDataConnector,
+)
 from great_expectations.datasource.new_datasource import BaseDatasource
 
 logger = logging.getLogger(__name__)
@@ -57,7 +60,7 @@ class SimpleSqlalchemyDatasource(BaseDatasource):
 
         # First, build DataConnectors for introspected assets
         for name, config in introspection_configs.items():
-            data_connector_config = dict(
+            data_connector_config: dict = dict(
                 **{
                     "class_name": "InferredAssetSqlDataConnector",
                     "name": name,
@@ -75,9 +78,9 @@ class SimpleSqlalchemyDatasource(BaseDatasource):
                 "partitioners"
             ].items():
 
-                data_connector_name = partitioner_name
+                data_connector_name: str = partitioner_name
                 if data_connector_name not in self.data_connectors:
-                    data_connector_config = {
+                    data_connector_config: dict = {
                         "class_name": "ConfiguredAssetSqlDataConnector",
                         "assets": {},
                     }
@@ -85,21 +88,16 @@ class SimpleSqlalchemyDatasource(BaseDatasource):
                         data_connector_name, data_connector_config
                     )
 
-                data_connector = self.data_connectors[data_connector_name]
+                data_connector: ConfiguredAssetSqlDataConnector = self.data_connectors[
+                    data_connector_name
+                ]
 
-                data_asset_config = copy.deepcopy(partitioner_config)
+                data_asset_config: dict = copy.deepcopy(partitioner_config)
                 data_asset_config["table_name"] = table_name
+                data_asset_name: str = table_name
 
-                data_asset_name_prefix = data_asset_config.pop(
-                    "data_asset_name_prefix", ""
-                )
-                data_asset_name_suffix = data_asset_config.pop(
-                    "data_asset_name_suffix", ""
-                )
-                data_asset_name = (
-                    data_asset_name_prefix + table_name + data_asset_name_suffix
-                )
-
+                # If config contains any prefix, suffix or schema_name values,
+                # they will be handled at the ConfiguredAssetSqlDataConnector-level
                 data_connector.add_data_asset(
                     data_asset_name,
                     data_asset_config,
