@@ -1,6 +1,7 @@
 import copy
 import logging
 from abc import ABC, abstractmethod
+from dataclasses import dataclass
 from enum import Enum
 from typing import Any, Callable, Dict, Iterable, Optional, Tuple, Union
 
@@ -138,6 +139,17 @@ class DataConnectorStorageDataReferenceResolver:
         )
 
 
+@dataclass
+class SplitDomainKwargs:
+    """compute_domain_kwargs, accessor_domain_kwargs when split from domain_kwargs
+
+    The union of compute_domain_kwargs, accessor_domain_kwargs is the input domain_kwargs
+    """
+
+    compute: dict
+    accessor: dict
+
+
 class ExecutionEngine(ABC):
     recognized_batch_spec_defaults = set()
 
@@ -353,10 +365,8 @@ class ExecutionEngine(ABC):
                 metric_fn, "metric_fn_type", MetricFunctionTypes.VALUE
             )
             if metric_fn_type in [
-                MetricPartialFunctionTypes.MAP_SERIES,
                 MetricPartialFunctionTypes.MAP_FN,
                 MetricPartialFunctionTypes.MAP_CONDITION_FN,
-                MetricPartialFunctionTypes.MAP_CONDITION_SERIES,
                 MetricPartialFunctionTypes.WINDOW_FN,
                 MetricPartialFunctionTypes.WINDOW_CONDITION_FN,
                 MetricPartialFunctionTypes.AGGREGATE_FN,
@@ -371,7 +381,11 @@ class ExecutionEngine(ABC):
                     raise ge_exceptions.MetricResolutionError(
                         message=str(e), failed_metrics=(metric_to_resolve,)
                     )
-            elif metric_fn_type == MetricFunctionTypes.VALUE:
+            elif metric_fn_type in [
+                MetricFunctionTypes.VALUE,
+                MetricPartialFunctionTypes.MAP_SERIES,
+                MetricPartialFunctionTypes.MAP_CONDITION_SERIES,
+            ]:
                 try:
                     resolved_metrics[metric_to_resolve.id] = metric_fn(
                         **metric_provider_kwargs
@@ -494,6 +508,224 @@ class ExecutionEngine(ABC):
             template_arguments=template_arguments,
         )
 
+    def _split_domain_kwargs(
+        self,
+        domain_kwargs: Dict,
+        domain_type: Union[str, MetricDomainTypes],
+        accessor_keys: Optional[Iterable[str]] = None,
+    ) -> SplitDomainKwargs:
+        """Split domain_kwargs for all domain types into compute and accessor domain kwargs.
+
+        Args:
+            domain_kwargs: A dictionary consisting of the domain kwargs specifying which data to obtain
+            domain_type: an Enum value indicating which metric domain the user would
+            like to be using, or a corresponding string value representing it. String types include "identity",
+            "column", "column_pair", "table" and "other". Enum types include capitalized versions of these from the
+            class MetricDomainTypes.
+            accessor_keys: keys that are part of the compute domain but should be ignored when
+            describing the domain and simply transferred with their associated values into accessor_domain_kwargs.
+
+        Returns:
+            compute_domain_kwargs, accessor_domain_kwargs from domain_kwargs
+            The union of compute_domain_kwargs, accessor_domain_kwargs is the input domain_kwargs
+        """
+        # Extracting value from enum if it is given for future computation
+        domain_type = MetricDomainTypes(domain_type)
+
+        # Warning user if accessor keys are in any domain that is not of type table, will be ignored
+        if (
+            domain_type != MetricDomainTypes.TABLE
+            and accessor_keys is not None
+            and len(list(accessor_keys)) > 0
+        ):
+            logger.warning(
+                'Accessor keys ignored since Metric Domain Type is not "table"'
+            )
+
+        split_domain_kwargs: SplitDomainKwargs
+        if domain_type == MetricDomainTypes.TABLE:
+            split_domain_kwargs = self._split_table_metric_domain_kwargs(
+                domain_kwargs, domain_type, accessor_keys
+            )
+
+        elif domain_type == MetricDomainTypes.COLUMN:
+            split_domain_kwargs = self._split_column_metric_domain_kwargs(
+                domain_kwargs,
+                domain_type,
+            )
+
+        elif domain_type == MetricDomainTypes.COLUMN_PAIR:
+            split_domain_kwargs = self._split_column_pair_metric_domain_kwargs(
+                domain_kwargs,
+                domain_type,
+            )
+
+        elif domain_type == MetricDomainTypes.MULTICOLUMN:
+            split_domain_kwargs = self._split_multi_column_metric_domain_kwargs(
+                domain_kwargs,
+                domain_type,
+            )
+        else:
+            compute_domain_kwargs = copy.deepcopy(domain_kwargs)
+            accessor_domain_kwargs = {}
+            split_domain_kwargs = SplitDomainKwargs(
+                compute_domain_kwargs, accessor_domain_kwargs
+            )
+
+        return split_domain_kwargs
+
+    @staticmethod
+    def _split_table_metric_domain_kwargs(
+        domain_kwargs: Dict,
+        domain_type: MetricDomainTypes,
+        accessor_keys: Optional[Iterable[str]] = None,
+    ) -> SplitDomainKwargs:
+        """Split domain_kwargs for table domain types into compute and accessor domain kwargs.
+
+        Args:
+            domain_kwargs: A dictionary consisting of the domain kwargs specifying which data to obtain
+            domain_type: an Enum value indicating which metric domain the user would
+            like to be using.
+            accessor_keys: keys that are part of the compute domain but should be ignored when
+            describing the domain and simply transferred with their associated values into accessor_domain_kwargs.
+
+        Returns:
+            compute_domain_kwargs, accessor_domain_kwargs from domain_kwargs
+            The union of compute_domain_kwargs, accessor_domain_kwargs is the input domain_kwargs
+        """
+        assert (
+            domain_type == MetricDomainTypes.TABLE
+        ), "This method only supports MetricDomainTypes.TABLE"
+
+        compute_domain_kwargs: Dict = copy.deepcopy(domain_kwargs)
+        accessor_domain_kwargs: Dict = {}
+
+        if accessor_keys is not None and len(list(accessor_keys)) > 0:
+            for key in accessor_keys:
+                accessor_domain_kwargs[key] = compute_domain_kwargs.pop(key)
+        if len(domain_kwargs.keys()) > 0:
+            # Warn user if kwarg not "normal".
+            unexpected_keys: set = set(compute_domain_kwargs.keys()).difference(
+                {
+                    "batch_id",
+                    "table",
+                    "row_condition",
+                    "condition_parser",
+                }
+            )
+            if len(unexpected_keys) > 0:
+                unexpected_keys_str: str = ", ".join(
+                    map(lambda element: f'"{element}"', unexpected_keys)
+                )
+                logger.warning(
+                    f'Unexpected key(s) {unexpected_keys_str} found in domain_kwargs for domain type "{domain_type.value}".'
+                )
+        return SplitDomainKwargs(compute_domain_kwargs, accessor_domain_kwargs)
+
+    @staticmethod
+    def _split_column_metric_domain_kwargs(
+        domain_kwargs: Dict,
+        domain_type: MetricDomainTypes,
+    ) -> SplitDomainKwargs:
+        """Split domain_kwargs for column domain types into compute and accessor domain kwargs.
+
+        Args:
+            domain_kwargs: A dictionary consisting of the domain kwargs specifying which data to obtain
+            domain_type: an Enum value indicating which metric domain the user would
+            like to be using.
+
+        Returns:
+            compute_domain_kwargs, accessor_domain_kwargs from domain_kwargs
+            The union of compute_domain_kwargs, accessor_domain_kwargs is the input domain_kwargs
+        """
+        assert (
+            domain_type == MetricDomainTypes.COLUMN
+        ), "This method only supports MetricDomainTypes.COLUMN"
+
+        compute_domain_kwargs: Dict = copy.deepcopy(domain_kwargs)
+        accessor_domain_kwargs: Dict = {}
+
+        if "column" not in compute_domain_kwargs:
+            raise ge_exceptions.GreatExpectationsError(
+                "Column not provided in compute_domain_kwargs"
+            )
+
+        accessor_domain_kwargs["column"] = compute_domain_kwargs.pop("column")
+
+        return SplitDomainKwargs(compute_domain_kwargs, accessor_domain_kwargs)
+
+    @staticmethod
+    def _split_column_pair_metric_domain_kwargs(
+        domain_kwargs: Dict,
+        domain_type: MetricDomainTypes,
+    ) -> SplitDomainKwargs:
+        """Split domain_kwargs for column pair domain types into compute and accessor domain kwargs.
+
+        Args:
+            domain_kwargs: A dictionary consisting of the domain kwargs specifying which data to obtain
+            domain_type: an Enum value indicating which metric domain the user would
+            like to be using.
+
+        Returns:
+            compute_domain_kwargs, accessor_domain_kwargs from domain_kwargs
+            The union of compute_domain_kwargs, accessor_domain_kwargs is the input domain_kwargs
+        """
+        assert (
+            domain_type == MetricDomainTypes.COLUMN_PAIR
+        ), "This method only supports MetricDomainTypes.COLUMN_PAIR"
+
+        compute_domain_kwargs: Dict = copy.deepcopy(domain_kwargs)
+        accessor_domain_kwargs: Dict = {}
+
+        if not ("column_A" in domain_kwargs and "column_B" in domain_kwargs):
+            raise ge_exceptions.GreatExpectationsError(
+                "column_A or column_B not found within domain_kwargs"
+            )
+
+        accessor_domain_kwargs["column_A"] = compute_domain_kwargs.pop("column_A")
+        accessor_domain_kwargs["column_B"] = compute_domain_kwargs.pop("column_B")
+
+        return SplitDomainKwargs(compute_domain_kwargs, accessor_domain_kwargs)
+
+    @staticmethod
+    def _split_multi_column_metric_domain_kwargs(
+        domain_kwargs: Dict,
+        domain_type: MetricDomainTypes,
+    ) -> SplitDomainKwargs:
+        """Split domain_kwargs for multicolumn domain types into compute and accessor domain kwargs.
+
+        Args:
+            domain_kwargs: A dictionary consisting of the domain kwargs specifying which data to obtain
+            domain_type: an Enum value indicating which metric domain the user would
+            like to be using.
+
+        Returns:
+            compute_domain_kwargs, accessor_domain_kwargs from domain_kwargs
+            The union of compute_domain_kwargs, accessor_domain_kwargs is the input domain_kwargs
+        """
+        assert (
+            domain_type == MetricDomainTypes.MULTICOLUMN
+        ), "This method only supports MetricDomainTypes.MULTICOLUMN"
+
+        compute_domain_kwargs: Dict = copy.deepcopy(domain_kwargs)
+        accessor_domain_kwargs: Dict = {}
+
+        if "column_list" not in domain_kwargs:
+            raise ge_exceptions.GreatExpectationsError(
+                "column_list not found within domain_kwargs"
+            )
+
+        column_list = compute_domain_kwargs.pop("column_list")
+
+        if len(column_list) < 2:
+            raise ge_exceptions.GreatExpectationsError(
+                "column_list must contain at least 2 columns"
+            )
+
+        accessor_domain_kwargs["column_list"] = column_list
+
+        return SplitDomainKwargs(compute_domain_kwargs, accessor_domain_kwargs)
+
 
 class MetricPartialFunctionTypes(Enum):
     MAP_FN = "map_fn"
