@@ -7,10 +7,7 @@ from scipy import stats as stats
 
 from great_expectations.core import ExpectationConfiguration
 from great_expectations.execution_engine import ExecutionEngine
-from great_expectations.execution_engine.execution_engine import MetricDomainTypes
 from great_expectations.execution_engine.util import (
-    build_categorical_partition_object,
-    build_continuous_partition_object,
     is_valid_categorical_partition_object,
     is_valid_partition_object,
 )
@@ -750,7 +747,7 @@ class ExpectColumnKlDivergenceToBeLessThan(ColumnExpectation):
                         "header": header,
                         "styling": {
                             "classes": [
-                                "col-" + str(chart_container_col_width),
+                                f"col-{str(chart_container_col_width)}",
                                 "mt-2",
                                 "pl-1",
                                 "pr-1",
@@ -766,7 +763,7 @@ class ExpectColumnKlDivergenceToBeLessThan(ColumnExpectation):
                         "graph": chart,
                         "styling": {
                             "classes": [
-                                "col-" + str(chart_container_col_width),
+                                f"col-{str(chart_container_col_width)}",
                                 "mt-2",
                                 "pl-1",
                                 "pr-1",
@@ -852,18 +849,14 @@ class ExpectColumnKlDivergenceToBeLessThan(ColumnExpectation):
                 if idx == len(fractions) - 1:
                     table_rows.append(
                         [
-                            "[{} - {}]".format(
-                                num_to_str(bins[idx]), num_to_str(bins[idx + 1])
-                            ),
+                            f"[{num_to_str(bins[idx])} - {num_to_str(bins[idx + 1])}]",
                             num_to_str(fraction),
                         ]
                     )
                 else:
                     table_rows.append(
                         [
-                            "[{} - {})".format(
-                                num_to_str(bins[idx]), num_to_str(bins[idx + 1])
-                            ),
+                            f"[{num_to_str(bins[idx])} - {num_to_str(bins[idx + 1])})",
                             num_to_str(fraction),
                         ]
                     )
@@ -1038,7 +1031,7 @@ class ExpectColumnKlDivergenceToBeLessThan(ColumnExpectation):
 
         # optionally, add column name
         if include_column_name:
-            header_template_str = "$column " + header_template_str
+            header_template_str = f"$column {header_template_str}"
 
         # generate table or chart depending on number of weights
         if len(weights) > 60:
@@ -1061,7 +1054,7 @@ class ExpectColumnKlDivergenceToBeLessThan(ColumnExpectation):
                 params["row_condition"], with_schema=True
             )
             header_template_str = (
-                conditional_template_str + ", then " + header_template_str
+                f"{conditional_template_str}, then {header_template_str}"
             )
             header_params_with_json_schema.update(conditional_params)
 
@@ -1180,14 +1173,14 @@ class ExpectColumnKlDivergenceToBeLessThan(ColumnExpectation):
             )
 
         if include_column_name:
-            template_str = "$column " + template_str
+            template_str = f"$column {template_str}"
 
         if params["row_condition"] is not None:
             (
                 conditional_template_str,
                 conditional_params,
             ) = parse_row_condition_string_pandas_engine(params["row_condition"])
-            template_str = conditional_template_str + ", then " + template_str
+            template_str = f"{conditional_template_str}, then {template_str}"
             params.update(conditional_params)
 
         expectation_string_obj = {
