@@ -1,8 +1,10 @@
 from typing import Optional
 
 from great_expectations.core.expectation_configuration import ExpectationConfiguration
-
-from ..expectation import ColumnPairMapExpectation, InvalidExpectationConfigurationError
+from great_expectations.expectations.expectation import (
+    ColumnPairMapExpectation,
+    InvalidExpectationConfigurationError,
+)
 
 
 class ExpectColumnPairValuesToBeInSet(ColumnPairMapExpectation):
@@ -63,7 +65,9 @@ class ExpectColumnPairValuesToBeInSet(ColumnPairMapExpectation):
         "value_pairs_set",
     )
 
-    def validate_configuration(self, configuration: Optional[ExpectationConfiguration]):
+    def validate_configuration(
+        self, configuration: Optional[ExpectationConfiguration]
+    ) -> bool:
         super().validate_configuration(configuration)
         if configuration is None:
             configuration = self.configuration
