@@ -2,16 +2,15 @@ import json
 from typing import Optional
 
 from great_expectations.core.expectation_configuration import ExpectationConfiguration
+from great_expectations.expectations.expectation import ColumnMapExpectation
 from great_expectations.expectations.util import render_evaluation_parameter_string
-
-from ...render.renderer.renderer import renderer
-from ...render.types import RenderedStringTemplateContent
-from ...render.util import (
+from great_expectations.render.renderer.renderer import renderer
+from great_expectations.render.types import RenderedStringTemplateContent
+from great_expectations.render.util import (
     num_to_str,
     parse_row_condition_string_pandas_engine,
     substitute_none_for_missing,
 )
-from ..expectation import ColumnMapExpectation
 
 try:
     import sqlalchemy as sa
@@ -94,7 +93,9 @@ class ExpectColumnValuesToMatchJsonSchema(ColumnMapExpectation):
         "json_schema",
     )
 
-    def validate_configuration(self, configuration: Optional[ExpectationConfiguration]):
+    def validate_configuration(
+        self, configuration: Optional[ExpectationConfiguration]
+    ) -> bool:
         super().validate_configuration(configuration)
 
         return True
@@ -142,9 +143,9 @@ class ExpectColumnValuesToMatchJsonSchema(ColumnMapExpectation):
         if not params.get("json_schema"):
             template_str = "values must match a JSON Schema but none was specified."
         else:
-            params["formatted_json"] = (
-                "<pre>" + json.dumps(params.get("json_schema"), indent=4) + "</pre>"
-            )
+            params[
+                "formatted_json"
+            ] = f"<pre>{json.dumps(params.get('json_schema'), indent=4)}</pre>"
             if params["mostly"] is not None:
                 params_with_json_schema["mostly_pct"]["value"] = num_to_str(
                     params["mostly"] * 100, precision=15, no_scientific=True
@@ -157,7 +158,7 @@ class ExpectColumnValuesToMatchJsonSchema(ColumnMapExpectation):
                 )
 
         if include_column_name:
-            template_str = "$column " + template_str
+            template_str = f"$column {template_str}"
 
         if params["row_condition"] is not None:
             (
@@ -166,7 +167,7 @@ class ExpectColumnValuesToMatchJsonSchema(ColumnMapExpectation):
             ) = parse_row_condition_string_pandas_engine(
                 params["row_condition"], with_schema=True
             )
-            template_str = conditional_template_str + ", then " + template_str
+            template_str = f"{conditional_template_str}, then {template_str}"
             params_with_json_schema.update(conditional_params)
 
         return (template_str, params_with_json_schema, styling)
@@ -196,9 +197,9 @@ class ExpectColumnValuesToMatchJsonSchema(ColumnMapExpectation):
         if not params.get("json_schema"):
             template_str = "values must match a JSON Schema but none was specified."
         else:
-            params["formatted_json"] = (
-                "<pre>" + json.dumps(params.get("json_schema"), indent=4) + "</pre>"
-            )
+            params[
+                "formatted_json"
+            ] = f"<pre>{json.dumps(params.get('json_schema'), indent=4)}</pre>"
             if params["mostly"] is not None:
                 params["mostly_pct"] = num_to_str(
                     params["mostly"] * 100, precision=15, no_scientific=True
@@ -211,14 +212,14 @@ class ExpectColumnValuesToMatchJsonSchema(ColumnMapExpectation):
                 )
 
         if include_column_name:
-            template_str = "$column " + template_str
+            template_str = f"$column {template_str}"
 
         if params["row_condition"] is not None:
             (
                 conditional_template_str,
                 conditional_params,
             ) = parse_row_condition_string_pandas_engine(params["row_condition"])
-            template_str = conditional_template_str + ", then " + template_str
+            template_str = f"{conditional_template_str}, then {template_str}"
             params.update(conditional_params)
 
         return [
