@@ -2,16 +2,18 @@ from datetime import datetime
 from typing import Optional
 
 from great_expectations.core.expectation_configuration import ExpectationConfiguration
+from great_expectations.expectations.expectation import (
+    ColumnMapExpectation,
+    InvalidExpectationConfigurationError,
+)
 from great_expectations.expectations.util import render_evaluation_parameter_string
-
-from ...render.renderer.renderer import renderer
-from ...render.types import RenderedStringTemplateContent
-from ...render.util import (
+from great_expectations.render.renderer.renderer import renderer
+from great_expectations.render.types import RenderedStringTemplateContent
+from great_expectations.render.util import (
     num_to_str,
     parse_row_condition_string_pandas_engine,
     substitute_none_for_missing,
 )
-from ..expectation import ColumnMapExpectation, InvalidExpectationConfigurationError
 
 
 class ExpectColumnValuesToMatchStrftimeFormat(ColumnMapExpectation):
@@ -82,7 +84,9 @@ class ExpectColumnValuesToMatchStrftimeFormat(ColumnMapExpectation):
         "strftime_format",
     )
 
-    def validate_configuration(self, configuration: Optional[ExpectationConfiguration]):
+    def validate_configuration(
+        self, configuration: Optional[ExpectationConfiguration]
+    ) -> bool:
         super().validate_configuration(configuration)
         if configuration is None:
             configuration = self.configuration
@@ -102,7 +106,7 @@ class ExpectColumnValuesToMatchStrftimeFormat(ColumnMapExpectation):
                     strftime_format,
                 )
         except ValueError as e:
-            raise ValueError("Unable to use provided strftime_format. " + str(e))
+            raise ValueError(f"Unable to use provided strftime_format. {str(e)}")
         except AssertionError as e:
             raise InvalidExpectationConfigurationError(str(e))
 
@@ -170,7 +174,7 @@ class ExpectColumnValuesToMatchStrftimeFormat(ColumnMapExpectation):
                 template_str += "."
 
         if include_column_name:
-            template_str = "$column " + template_str
+            template_str = f"$column {template_str}"
 
         if params["row_condition"] is not None:
             (
@@ -179,7 +183,7 @@ class ExpectColumnValuesToMatchStrftimeFormat(ColumnMapExpectation):
             ) = parse_row_condition_string_pandas_engine(
                 params["row_condition"], with_schema=True
             )
-            template_str = conditional_template_str + ", then " + template_str
+            template_str = f"{conditional_template_str}, then {template_str}"
             params_with_json_schema.update(conditional_params)
 
         return (template_str, params_with_json_schema, styling)
@@ -228,14 +232,14 @@ class ExpectColumnValuesToMatchStrftimeFormat(ColumnMapExpectation):
                 template_str += "."
 
         if include_column_name:
-            template_str = "$column " + template_str
+            template_str = f"$column {template_str}"
 
         if params["row_condition"] is not None:
             (
                 conditional_template_str,
                 conditional_params,
             ) = parse_row_condition_string_pandas_engine(params["row_condition"])
-            template_str = conditional_template_str + ", then " + template_str
+            template_str = f"{conditional_template_str}, then {template_str}"
             params.update(conditional_params)
 
         return [
