@@ -1,19 +1,21 @@
 from typing import Optional
 
 from great_expectations.core.expectation_configuration import ExpectationConfiguration
+from great_expectations.expectations.expectation import (
+    ColumnMapExpectation,
+    InvalidExpectationConfigurationError,
+)
 from great_expectations.expectations.util import (
     add_values_with_json_schema_from_list_in_params,
     render_evaluation_parameter_string,
 )
-
-from ...render.renderer.renderer import renderer
-from ...render.types import RenderedStringTemplateContent
-from ...render.util import (
+from great_expectations.render.renderer.renderer import renderer
+from great_expectations.render.types import RenderedStringTemplateContent
+from great_expectations.render.util import (
     num_to_str,
     parse_row_condition_string_pandas_engine,
     substitute_none_for_missing,
 )
-from ..expectation import ColumnMapExpectation, InvalidExpectationConfigurationError
 
 
 class ExpectColumnValuesToNotMatchRegexList(ColumnMapExpectation):
@@ -90,7 +92,9 @@ class ExpectColumnValuesToNotMatchRegexList(ColumnMapExpectation):
         "regex_list",
     )
 
-    def validate_configuration(self, configuration: Optional[ExpectationConfiguration]):
+    def validate_configuration(
+        self, configuration: Optional[ExpectationConfiguration]
+    ) -> bool:
         super().validate_configuration(configuration)
         if configuration is None:
             configuration = self.configuration
@@ -160,9 +164,9 @@ class ExpectColumnValuesToNotMatchRegexList(ColumnMapExpectation):
             values_string = "[ ]"
         else:
             for i, v in enumerate(params["regex_list"]):
-                params["v__" + str(i)] = v
+                params[f"v__{str(i)}"] = v
             values_string = " ".join(
-                ["$v__" + str(i) for i, v in enumerate(params["regex_list"])]
+                [f"$v__{str(i)}" for i, v in enumerate(params["regex_list"])]
             )
 
         template_str = (
@@ -180,7 +184,7 @@ class ExpectColumnValuesToNotMatchRegexList(ColumnMapExpectation):
             template_str += "."
 
         if include_column_name:
-            template_str = "$column " + template_str
+            template_str = f"$column {template_str}"
 
         if params["row_condition"] is not None:
             (
@@ -189,7 +193,7 @@ class ExpectColumnValuesToNotMatchRegexList(ColumnMapExpectation):
             ) = parse_row_condition_string_pandas_engine(
                 params["row_condition"], with_schema=True
             )
-            template_str = conditional_template_str + ", then " + template_str
+            template_str = f"{conditional_template_str}, then {template_str}"
             params_with_json_schema.update(conditional_params)
 
         params_with_json_schema = add_values_with_json_schema_from_list_in_params(
@@ -225,9 +229,9 @@ class ExpectColumnValuesToNotMatchRegexList(ColumnMapExpectation):
             values_string = "[ ]"
         else:
             for i, v in enumerate(params["regex_list"]):
-                params["v__" + str(i)] = v
+                params[f"v__{str(i)}"] = v
             values_string = " ".join(
-                ["$v__" + str(i) for i, v in enumerate(params["regex_list"])]
+                [f"$v__{str(i)}" for i, v in enumerate(params["regex_list"])]
             )
 
         template_str = (
@@ -245,14 +249,14 @@ class ExpectColumnValuesToNotMatchRegexList(ColumnMapExpectation):
             template_str += "."
 
         if include_column_name:
-            template_str = "$column " + template_str
+            template_str = f"$column {template_str}"
 
         if params["row_condition"] is not None:
             (
                 conditional_template_str,
                 conditional_params,
             ) = parse_row_condition_string_pandas_engine(params["row_condition"])
-            template_str = conditional_template_str + ", then " + template_str
+            template_str = f"{conditional_template_str}, then {template_str}"
             params.update(conditional_params)
 
         return [
