@@ -1,10 +1,7 @@
 from great_expectations.expectations.expectation import MulticolumnMapExpectation
 from great_expectations.expectations.util import render_evaluation_parameter_string
 from great_expectations.render.renderer.renderer import renderer
-from great_expectations.render.types import (
-    RenderedStringTemplateContent,
-    RenderedTableContent,
-)
+from great_expectations.render.types import RenderedStringTemplateContent
 from great_expectations.render.util import (
     num_to_str,
     parse_row_condition_string_pandas_engine,
@@ -170,12 +167,12 @@ class ExpectCompoundColumnsToBeUnique(MulticolumnMapExpectation):
             f"Values for given compound columns must be unique together{mostly_str}: "
         )
         for idx in range(len(params["column_list"]) - 1):
-            template_str += "$column_list_" + str(idx) + ", "
-            params["column_list_" + str(idx)] = params["column_list"][idx]
+            template_str += f"$column_list_{str(idx)}, "
+            params[f"column_list_{str(idx)}"] = params["column_list"][idx]
 
         last_idx = len(params["column_list"]) - 1
-        template_str += "$column_list_" + str(last_idx)
-        params["column_list_" + str(last_idx)] = params["column_list"][last_idx]
+        template_str += f"$column_list_{str(last_idx)}"
+        params[f"column_list_{str(last_idx)}"] = params["column_list"][last_idx]
 
         if params["row_condition"] is not None:
             (
