@@ -207,12 +207,12 @@ class ExpectSelectColumnValuesToBeUniqueWithinRecord(MulticolumnMapExpectation):
 
         template_str = f"Values must always be unique across columns{mostly_str}: "
         for idx in range(len(params["column_list"]) - 1):
-            template_str += "$column_list_" + str(idx) + ", "
-            params["column_list_" + str(idx)] = params["column_list"][idx]
+            template_str += f"$column_list_{str(idx)}, "
+            params[f"column_list_{str(idx)}"] = params["column_list"][idx]
 
         last_idx = len(params["column_list"]) - 1
-        template_str += "$column_list_" + str(last_idx)
-        params["column_list_" + str(last_idx)] = params["column_list"][last_idx]
+        template_str += f"$column_list_{str(last_idx)}"
+        params[f"column_list_{str(last_idx)}"] = params["column_list"][last_idx]
 
         if params["row_condition"] is not None:
             (
