@@ -1,13 +1,11 @@
 import datetime
 import warnings
-from typing import Any, Dict, Optional
+from typing import Any, Dict
 
 import pandas as pd
 from dateutil.parser import parse
 
-from great_expectations.core import ExpectationConfiguration
 from great_expectations.execution_engine import (
-    ExecutionEngine,
     PandasExecutionEngine,
     SparkDFExecutionEngine,
 )
@@ -21,7 +19,6 @@ from great_expectations.expectations.metrics.map_metric_provider import (
     column_condition_partial,
 )
 from great_expectations.expectations.metrics.metric_provider import metric_partial
-from great_expectations.validator.metric_configuration import MetricConfiguration
 
 
 class ColumnValuesDecreasing(ColumnMapMetricProvider):
