@@ -173,8 +173,7 @@ def setup_notebook_logging(logger=None, log_level=logging.INFO):
     logger.addHandler(chandler)
     logger.setLevel(log_level)
     logger.info(
-        "Great Expectations logging enabled at %s level by JupyterUX module."
-        % (log_level,)
+        f"Great Expectations logging enabled at {log_level} level by JupyterUX module."
     )
     #
     # # Filter warnings
