@@ -21,7 +21,7 @@ class Validator:
 
     def __repr__(self) -> str:
         args = self._repr_args()
-        args = "{}, ".format(args) if args else ""
+        args = f"{args}, " if args else ""
 
         return "<{self.__class__.__name__}({args}error={self.error!r})>".format(
             self=self, args=args
@@ -95,7 +95,7 @@ class URL(Validator):
         relative: bool = False,
         schemes: types.StrSequenceOrSet = None,
         require_tld: bool = True,
-        error: str = None
+        error: str = None,
     ):
         self.relative = relative
         self.error = error or self.default_message  # type: str
@@ -103,7 +103,7 @@ class URL(Validator):
         self.require_tld = require_tld
 
     def _repr_args(self) -> str:
-        return "relative={!r}".format(self.relative)
+        return f"relative={self.relative!r}"
 
     def _format_error(self, value) -> str:
         return self.error.format(input=value)
@@ -222,7 +222,7 @@ class Range(Validator):
         *,
         min_inclusive: bool = True,
         max_inclusive: bool = True,
-        error: str = None
+        error: str = None,
     ):
         self.min = min
         self.max = max
@@ -301,7 +301,7 @@ class Length(Validator):
         self.equal = equal
 
     def _repr_args(self) -> str:
-        return "min={!r}, max={!r}, equal={!r}".format(self.min, self.max, self.equal)
+        return f"min={self.min!r}, max={self.max!r}, equal={self.equal!r}"
 
     def _format_error(self, value, message: str) -> str:
         return (self.error or message).format(
@@ -343,7 +343,7 @@ class Equal(Validator):
         self.error = error or self.default_message  # type: str
 
     def _repr_args(self) -> str:
-        return "comparable={!r}".format(self.comparable)
+        return f"comparable={self.comparable!r}"
 
     def _format_error(self, value) -> str:
         return self.error.format(input=value, other=self.comparable)
@@ -376,7 +376,7 @@ class Regexp(Validator):
         regex: typing.Union[str, bytes, typing.Pattern],
         flags=0,
         *,
-        error: str = None
+        error: str = None,
     ):
         self.regex = (
             re.compile(regex, flags) if isinstance(regex, (str, bytes)) else regex
@@ -384,7 +384,7 @@ class Regexp(Validator):
         self.error = error or self.default_message  # type: str
 
     def _repr_args(self) -> str:
-        return "regex={!r}".format(self.regex)
+        return f"regex={self.regex!r}"
 
     def _format_error(self, value) -> str:
         return self.error.format(input=value, regex=self.regex.pattern)
@@ -416,7 +416,7 @@ class Predicate(Validator):
         self.kwargs = kwargs
 
     def _repr_args(self) -> str:
-        return "method={!r}, kwargs={!r}".format(self.method, self.kwargs)
+        return f"method={self.method!r}, kwargs={self.kwargs!r}"
 
     def _format_error(self, value) -> str:
         return self.error.format(input=value, method=self.method)
@@ -446,7 +446,7 @@ class NoneOf(Validator):
         self.error = error or self.default_message  # type: str
 
     def _repr_args(self) -> str:
-        return "iterable={!r}".format(self.iterable)
+        return f"iterable={self.iterable!r}"
 
     def _format_error(self, value) -> str:
         return self.error.format(input=value, values=self.values_text)
@@ -477,7 +477,7 @@ class OneOf(Validator):
         choices: typing.Iterable,
         labels: typing.Iterable[str] = None,
         *,
-        error: str = None
+        error: str = None,
     ):
         self.choices = choices
         self.choices_text = ", ".join(str(choice) for choice in self.choices)
@@ -486,7 +486,7 @@ class OneOf(Validator):
         self.error = error or self.default_message  # type: str
 
     def _repr_args(self) -> str:
-        return "choices={!r}, labels={!r}".format(self.choices, self.labels)
+        return f"choices={self.choices!r}, labels={self.labels!r}"
 
     def _format_error(self, value) -> str:
         return self.error.format(
