@@ -6,7 +6,8 @@ import jsonschema
 
 from great_expectations.core.expectation_configuration import ExpectationConfiguration
 from great_expectations.core.expectation_suite import ExpectationSuite
-from great_expectations.profile.base import Profiler, ProfilerTypeMapping
+from great_expectations.core.profiler_types_mapping import ProfilerTypeMapping
+from great_expectations.profile.base import Profiler
 
 logger = logging.getLogger(__name__)
 
@@ -55,11 +56,11 @@ class JsonSchemaProfiler(Profiler):
             )
         if "type" not in schema.keys():
             raise KeyError(
-                f"This profiler requires a json schema with a top level `type` key"
+                "This profiler requires a json schema with a top level `type` key"
             )
         if schema["type"] != JsonSchemaTypes.OBJECT.value:
             raise TypeError(
-                f"This profiler requires a json schema with a top level `type` of `object`"
+                "This profiler requires a json schema with a top level `type` of `object`"
             )
         validator = jsonschema.validators.validator_for(schema)
         validator.check_schema(schema)
