@@ -5,17 +5,15 @@ from typing import Dict, List, Tuple, Union
 
 from dateutil.parser import parse
 
+from great_expectations.core import ExpectationSuite
+from great_expectations.core.expectation_validation_result import (
+    ExpectationSuiteValidationResult,
+)
+from great_expectations.core.run_identifier import RunIdentifier
 from great_expectations.data_context.util import instantiate_class_from_config
 from great_expectations.exceptions import ClassInstantiationError
-from great_expectations.render.util import num_to_str
-
-from ...core import ExpectationSuite
-from ...core.expectation_validation_result import ExpectationSuiteValidationResult
-from ...core.run_identifier import RunIdentifier
-from ...validation_operators.types.validation_operator_result import (
-    ValidationOperatorResult,
-)
-from ..types import (
+from great_expectations.render.renderer.renderer import Renderer
+from great_expectations.render.types import (
     CollapseContent,
     RenderedComponentContent,
     RenderedDocumentContent,
@@ -26,7 +24,10 @@ from ..types import (
     RenderedTableContent,
     TextContent,
 )
-from .renderer import Renderer
+from great_expectations.render.util import num_to_str
+from great_expectations.validation_operators.types.validation_operator_result import (
+    ValidationOperatorResult,
+)
 
 logger = logging.getLogger(__name__)
 
@@ -361,7 +362,7 @@ class ValidationResultsPageRenderer(Renderer):
             + str(expectation_suite_name).split(".")
         )
         expectation_suite_path = (
-            os.path.join(*expectation_suite_path_components) + ".html"
+            f"{os.path.join(*expectation_suite_path_components)}.html"
         )
         # TODO: deprecate dual batch api support in 0.14
         batch_kwargs = (
@@ -608,7 +609,7 @@ class ValidationResultsPageRenderer(Renderer):
                 if key == "success_percent":
                     # table_rows.append([value, "{0:.2f}%".format(statistics[key])])
                     table_rows.append(
-                        [value, num_to_str(statistics[key], precision=4) + "%"]
+                        [value, f"{num_to_str(statistics[key], precision=4)}%"]
                     )
                 else:
                     table_rows.append([value, statistics[key]])
@@ -704,7 +705,7 @@ class ExpectationSuitePageRenderer(Renderer):
         return RenderedDocumentContent(
             **{
                 "renderer_type": "ExpectationSuitePageRenderer",
-                "page_title": "Expectations / " + str(expectation_suite_name),
+                "page_title": f"Expectations / {str(expectation_suite_name)}",
                 "expectation_suite_name": expectation_suite_name,
                 "utm_medium": "expectation-suite-page",
                 "sections": sections,
@@ -986,12 +987,12 @@ class ProfilingResultsPageRenderer(Renderer):
         if run_name_as_time != run_time_datetime and run_name_as_time != "__none__":
             include_run_name = True
 
-        page_title = "Profiling Results / " + str(expectation_suite_name)
+        page_title = f"Profiling Results / {str(expectation_suite_name)}"
         if data_asset_name:
-            page_title += " / " + str(data_asset_name)
+            page_title += f" / {str(data_asset_name)}"
         if include_run_name:
-            page_title += " / " + str(run_name)
-        page_title += " / " + str(run_time)
+            page_title += f" / {str(run_name)}"
+        page_title += f" / {str(run_time)}"
 
         return RenderedDocumentContent(
             **{
