@@ -484,7 +484,7 @@ class DefaultSiteSectionBuilder:
                         viewable_content,
                     )
             except Exception as e:
-                exception_message = f"""\
+                exception_message = """\
 An unexpected Exception occurred during data docs rendering.  Because of this error, certain parts of data docs will \
 not be rendered properly and/or may not appear altogether.  Please use the trace, included in this message, to \
 diagnose and repair the underlying issue.  Detailed information follows:
@@ -584,8 +584,8 @@ class DefaultSiteIndexBuilder:
     ):
         import os
 
-        if section_name + "_links" not in index_links_dict:
-            index_links_dict[section_name + "_links"] = []
+        if f"{section_name}_links" not in index_links_dict:
+            index_links_dict[f"{section_name}_links"] = []
 
         if run_id:
             filepath = (
@@ -608,7 +608,7 @@ class DefaultSiteIndexBuilder:
         )
         expectation_suite_filepath += ".html"
 
-        index_links_dict[section_name + "_links"].append(
+        index_links_dict[f"{section_name}_links"].append(
             {
                 "expectation_suite_name": expectation_suite_name,
                 "filepath": filepath,
@@ -755,7 +755,7 @@ class DefaultSiteIndexBuilder:
                 show_how_to_buttons=self.show_how_to_buttons,
             )
         except Exception as e:
-            exception_message = f"""\
+            exception_message = """\
 An unexpected Exception occurred during data docs rendering.  Because of this error, certain parts of data docs will \
 not be rendered properly and/or may not appear altogether.  Please use the trace, included in this message, to \
 diagnose and repair the underlying issue.  Detailed information follows:
