@@ -45,7 +45,7 @@ def num_to_str(f, precision=DEFAULT_PRECISION, use_locale=False, no_scientific=F
     # So, if it's not already a float, we will append a decimal point to the string representation
     s = repr(f)
     if not isinstance(f, float):
-        s += locale.localeconv().get("decimal_point") + "0"
+        s += f"{locale.localeconv().get('decimal_point')}0"
     d = local_context.create_decimal(s)
     if no_scientific:
         result = format(d, "f")
@@ -56,7 +56,7 @@ def num_to_str(f, precision=DEFAULT_PRECISION, use_locale=False, no_scientific=F
     if f != locale.atof(result):
         # result = '≈' + result
         #  ≈  # \u2248
-        result = "≈" + result
+        result = f"≈{result}"
     decimal_char = locale.localeconv().get("decimal_point")
     if "e" not in result and "E" not in result and decimal_char in result:
         result = result.rstrip("0").rstrip(decimal_char)
@@ -171,14 +171,14 @@ def parse_row_condition_string_pandas_engine(
         param_value = condition.replace(" NOT ", " not ")
 
         if with_schema:
-            params["row_condition__" + str(i)] = {
+            params[f"row_condition__{str(i)}"] = {
                 "schema": {"type": "string"},
                 "value": param_value,
             }
         else:
-            params["row_condition__" + str(i)] = param_value
+            params[f"row_condition__{str(i)}"] = param_value
             condition_string = condition_string.replace(
-                condition, "$row_condition__" + str(i)
+                condition, f"$row_condition__{str(i)}"
             )
 
     template_str += condition_string.lower()
