@@ -17,6 +17,7 @@ from great_expectations.data_context.types.resource_identifiers import (
     ExpectationSuiteIdentifier,
     ValidationResultIdentifier,
 )
+from great_expectations.util import is_library_loadable
 from great_expectations.validation_operators import (
     CloudNotificationAction,
     EmailAction,
@@ -98,18 +99,15 @@ def test_StoreAction():
     )
     assert stored_identifier.run_id == expected_run_id
 
-    assert (
-        fake_in_memory_store.get(
-            ValidationResultIdentifier(
-                expectation_suite_identifier=ExpectationSuiteIdentifier(
-                    expectation_suite_name="default_expectations"
-                ),
-                run_id=expected_run_id,
-                batch_identifier="1234",
-            )
+    assert fake_in_memory_store.get(
+        ValidationResultIdentifier(
+            expectation_suite_identifier=ExpectationSuiteIdentifier(
+                expectation_suite_name="default_expectations"
+            ),
+            run_id=expected_run_id,
+            batch_identifier="1234",
         )
-        == ExpectationSuiteValidationResult(success=False, results=[])
-    )
+    ) == ExpectationSuiteValidationResult(success=False, results=[])
 
 
 @mock.patch.object(Session, "post", return_value=MockSlackResponse(200))
@@ -135,14 +133,11 @@ def test_SlackNotificationAction(
         notify_on=notify_on,
     )
 
-    assert (
-        slack_action.run(
-            validation_result_suite_identifier=validation_result_suite_id,
-            validation_result_suite=validation_result_suite,
-            data_asset=None,
-        )
-        == {"slack_notification_result": "Slack notification succeeded."}
-    )
+    assert slack_action.run(
+        validation_result_suite_identifier=validation_result_suite_id,
+        validation_result_suite=validation_result_suite,
+        data_asset=None,
+    ) == {"slack_notification_result": "Slack notification succeeded."}
 
     # Test with slack_token and slack_channel set; expect pass
     slack_action = SlackNotificationAction(
@@ -153,14 +148,11 @@ def test_SlackNotificationAction(
         notify_on=notify_on,
     )
 
-    assert (
-        slack_action.run(
-            validation_result_suite_identifier=validation_result_suite_id,
-            validation_result_suite=validation_result_suite,
-            data_asset=None,
-        )
-        == {"slack_notification_result": "Slack notification succeeded."}
-    )
+    assert slack_action.run(
+        validation_result_suite_identifier=validation_result_suite_id,
+        validation_result_suite=validation_result_suite,
+        data_asset=None,
+    ) == {"slack_notification_result": "Slack notification succeeded."}
 
     # Test with just slack_token set; expect fail
     with pytest.raises(AssertionError):
@@ -200,21 +192,18 @@ def test_SlackNotificationAction(
         notify_on=notify_on,
     )
 
-    assert (
-        slack_action.run(
-            validation_result_suite_identifier=validation_result_suite_id,
-            validation_result_suite=ExpectationSuiteValidationResult(
-                success=False,
-                results=[],
-                statistics={
-                    "successful_expectations": [],
-                    "evaluated_expectations": [],
-                },
-            ),
-            data_asset=None,
-        )
-        == {"slack_notification_result": "Slack notification succeeded."}
-    )
+    assert slack_action.run(
+        validation_result_suite_identifier=validation_result_suite_id,
+        validation_result_suite=ExpectationSuiteValidationResult(
+            success=False,
+            results=[],
+            statistics={
+                "successful_expectations": [],
+                "evaluated_expectations": [],
+            },
+        ),
+        data_asset=None,
+    ) == {"slack_notification_result": "Slack notification succeeded."}
 
     # test notify on with successful run; expect pass
     notify_on = "failure"
@@ -226,23 +215,24 @@ def test_SlackNotificationAction(
         notify_on=notify_on,
     )
 
-    assert (
-        slack_action.run(
-            validation_result_suite_identifier=validation_result_suite_id,
-            validation_result_suite=ExpectationSuiteValidationResult(
-                success=True,
-                results=[],
-                statistics={
-                    "successful_expectations": [],
-                    "evaluated_expectations": [],
-                },
-            ),
-            data_asset=None,
-        )
-        == {"slack_notification_result": "none required"}
-    )
+    assert slack_action.run(
+        validation_result_suite_identifier=validation_result_suite_id,
+        validation_result_suite=ExpectationSuiteValidationResult(
+            success=True,
+            results=[],
+            statistics={
+                "successful_expectations": [],
+                "evaluated_expectations": [],
+            },
+        ),
+        data_asset=None,
+    ) == {"slack_notification_result": "none required"}
 
 
+@pytest.mark.skipif(
+    not is_library_loadable(library_name="pypd"),
+    reason="pypd is not installed",
+)
 @mock.patch("pypd.EventV2")
 def test_PagerdutyAlertAction(
     data_context_parameterized_expectation_suite,
@@ -261,26 +251,20 @@ def test_PagerdutyAlertAction(
     # Make sure the alert is sent by default when the validation has success = False
     validation_result_suite.success = False
 
-    assert (
-        pagerduty_action.run(
-            validation_result_suite_identifier=validation_result_suite_id,
-            validation_result_suite=validation_result_suite,
-            data_asset=None,
-        )
-        == {"pagerduty_alert_result": "success"}
-    )
+    assert pagerduty_action.run(
+        validation_result_suite_identifier=validation_result_suite_id,
+        validation_result_suite=validation_result_suite,
+        data_asset=None,
+    ) == {"pagerduty_alert_result": "success"}
 
     # Make sure the alert is not sent by default when the validation has success = True
     validation_result_suite.success = True
 
-    assert (
-        pagerduty_action.run(
-            validation_result_suite_identifier=validation_result_suite_id,
-            validation_result_suite=validation_result_suite,
-            data_asset=None,
-        )
-        == {"pagerduty_alert_result": "none sent"}
-    )
+    assert pagerduty_action.run(
+        validation_result_suite_identifier=validation_result_suite_id,
+        validation_result_suite=validation_result_suite,
+        data_asset=None,
+    ) == {"pagerduty_alert_result": "none sent"}
 
 
 def test_OpsgenieAlertAction(
@@ -305,26 +289,20 @@ def test_OpsgenieAlertAction(
     # Make sure the alert is sent by default when the validation has success = False
     validation_result_suite.success = False
 
-    assert (
-        opsgenie_action.run(
-            validation_result_suite_identifier=validation_result_suite_id,
-            validation_result_suite=validation_result_suite,
-            data_asset=None,
-        )
-        == {"opsgenie_alert_result": "error"}
-    )
+    assert opsgenie_action.run(
+        validation_result_suite_identifier=validation_result_suite_id,
+        validation_result_suite=validation_result_suite,
+        data_asset=None,
+    ) == {"opsgenie_alert_result": "error"}
 
     # Make sure the alert is not sent by default when the validation has success = True
     validation_result_suite.success = True
 
-    assert (
-        opsgenie_action.run(
-            validation_result_suite_identifier=validation_result_suite_id,
-            validation_result_suite=validation_result_suite,
-            data_asset=None,
-        )
-        == {"opsgenie_alert_result": "error"}
-    )
+    assert opsgenie_action.run(
+        validation_result_suite_identifier=validation_result_suite_id,
+        validation_result_suite=validation_result_suite,
+        data_asset=None,
+    ) == {"opsgenie_alert_result": "error"}
 
 
 @mock.patch.object(Session, "post", return_value=MockTeamsResponse(200))
@@ -382,14 +360,11 @@ def test_MicrosoftTeamsNotificationAction_good_request(
         microsoft_teams_webhook=teams_webhook,
         notify_on=notify_on,
     )
-    assert (
-        teams_action.run(
-            validation_result_suite_identifier=validation_result_suite_extended_id,
-            validation_result_suite=validation_result_suite,
-            data_asset=None,
-        )
-        == {"microsoft_teams_notification_result": None}
-    )
+    assert teams_action.run(
+        validation_result_suite_identifier=validation_result_suite_extended_id,
+        validation_result_suite=validation_result_suite,
+        data_asset=None,
+    ) == {"microsoft_teams_notification_result": None}
 
     validation_result_suite.success = True
     notify_on = "success"
@@ -433,14 +408,11 @@ def test_MicrosoftTeamsNotificationAction_good_request(
         microsoft_teams_webhook=teams_webhook,
         notify_on=notify_on,
     )
-    assert (
-        teams_action.run(
-            validation_result_suite_identifier=validation_result_suite_extended_id,
-            validation_result_suite=validation_result_suite,
-            data_asset=None,
-        )
-        == {"microsoft_teams_notification_result": None}
-    )
+    assert teams_action.run(
+        validation_result_suite_identifier=validation_result_suite_extended_id,
+        validation_result_suite=validation_result_suite,
+        data_asset=None,
+    ) == {"microsoft_teams_notification_result": None}
 
 
 @mock.patch.object(Session, "post", return_value=MockTeamsResponse(400))
@@ -465,19 +437,13 @@ def test_MicrosoftTeamsNotificationAction_bad_request(
         microsoft_teams_webhook=teams_webhook,
         notify_on=notify_on,
     )
-    assert (
-        teams_action.run(
-            validation_result_suite_identifier=validation_result_suite_extended_id,
-            validation_result_suite=validation_result_suite,
-            data_asset=None,
-        )
-        == {"microsoft_teams_notification_result": None}
-    )
+    assert teams_action.run(
+        validation_result_suite_identifier=validation_result_suite_extended_id,
+        validation_result_suite=validation_result_suite,
+        data_asset=None,
+    ) == {"microsoft_teams_notification_result": None}
 
-    assert (
-        "Request to Microsoft Teams webhook at http://testing returned error 400"
-        in caplog.text
-    )
+    assert "Request to Microsoft Teams webhook returned error 400" in caplog.text
 
 
 class MockSMTPServer:
@@ -604,14 +570,11 @@ def test_EmailAction(
             use_ssl=use_ssl,
         )
         assert email_action.sender_login != email_action.sender_alias
-        assert (
-            email_action.run(
-                validation_result_suite_identifier=validation_result_suite_id,
-                validation_result_suite=validation_result_suite,
-                data_asset=None,
-            )
-            == {"email_result": expected}
-        )
+        assert email_action.run(
+            validation_result_suite_identifier=validation_result_suite_id,
+            validation_result_suite=validation_result_suite,
+            data_asset=None,
+        ) == {"email_result": expected}
 
 
 # def test_ExtractAndStoreEvaluationParamsAction():
@@ -668,7 +631,7 @@ def test_cloud_notification_action(
     )
     expected_ge_cloud_url = urljoin(
         cloud_action.data_context.ge_cloud_config.base_url,
-        f"/accounts/{cloud_action.data_context.ge_cloud_config.account_id}/contracts/"
+        f"/organizations/{cloud_action.data_context.ge_cloud_config.organization_id}/contracts/"
         f"{cloud_action.checkpoint_ge_cloud_id}/suite-validation-results/{validation_result_suite_ge_cloud_identifier.ge_cloud_id}/notification-actions",
     )
     expected_headers = {
@@ -676,14 +639,11 @@ def test_cloud_notification_action(
         "Authorization": f"Bearer {ge_cloud_access_token}",
     }
 
-    assert (
-        cloud_action.run(
-            validation_result_suite=validation_result_suite_with_ge_cloud_id,
-            validation_result_suite_identifier=validation_result_suite_ge_cloud_identifier,
-            data_asset=None,
-        )
-        == {"cloud_notification_result": "Cloud notification succeeded."}
-    )
+    assert cloud_action.run(
+        validation_result_suite=validation_result_suite_with_ge_cloud_id,
+        validation_result_suite_identifier=validation_result_suite_ge_cloud_identifier,
+        data_asset=None,
+    ) == {"cloud_notification_result": "Cloud notification succeeded."}
     mock_post_method.assert_called_with(
         url=expected_ge_cloud_url, headers=expected_headers
     )
@@ -704,7 +664,7 @@ def test_cloud_notification_action_bad_response(
     )
     expected_ge_cloud_url = urljoin(
         cloud_action.data_context.ge_cloud_config.base_url,
-        f"/accounts/{cloud_action.data_context.ge_cloud_config.account_id}/contracts/"
+        f"/organizations/{cloud_action.data_context.ge_cloud_config.organization_id}/contracts/"
         f"{cloud_action.checkpoint_ge_cloud_id}/suite-validation-results/{validation_result_suite_ge_cloud_identifier.ge_cloud_id}/notification-actions",
     )
     expected_headers = {
@@ -712,9 +672,7 @@ def test_cloud_notification_action_bad_response(
         "Authorization": f"Bearer {ge_cloud_access_token}",
     }
     expected_result = {
-        "cloud_notification_result": "Cloud Notification request at "
-        "https://app.test.greatexpectations.io/accounts/bd20fead-2c31-4392-bcd1-f1e87ad5a79c/contracts/bfe7dc64-5320-49b0-91c1-2e8029e06c4d/suite-validation-results/bfe7dc64-5320-49b0-91c1-2e8029e06c4d/notification-actions "
-        "returned error 418: test_text"
+        "cloud_notification_result": "Cloud Notification request returned error 418: test_text"
     }
 
     assert (
