@@ -2,20 +2,11 @@ import configparser
 import os
 import shutil
 from copy import deepcopy
+from unittest import mock
 
-import jsonschema
-import mock
 import pytest
 
-from great_expectations.core.usage_statistics.schemas import (
-    anonymized_datasource_schema,
-    cli_new_ds_choice_payload,
-    init_payload_schema,
-    save_or_edit_expectation_suite_payload_schema,
-    usage_statistics_record_schema,
-)
 from great_expectations.core.usage_statistics.usage_statistics import (
-    add_datasource_usage_statistics,
     run_validation_operator_usage_statistics,
 )
 from great_expectations.data_context import BaseDataContext, DataContext
@@ -39,8 +30,12 @@ def in_memory_data_context_config_usage_stats_enabled():
             "config_variables_file_path": None,
             "datasources": {},
             "stores": {
-                "expectations_store": {"class_name": "ExpectationsStore",},
-                "validations_store": {"class_name": "ValidationsStore",},
+                "expectations_store": {
+                    "class_name": "ExpectationsStore",
+                },
+                "validations_store": {
+                    "class_name": "ValidationsStore",
+                },
                 "evaluation_parameter_store": {
                     "class_name": "EvaluationParameterStore",
                 },
@@ -310,6 +305,35 @@ def test_opt_out_env_var_overrides_yml(tmp_path_factory, monkeypatch):
     assert project_config.anonymous_usage_statistics.enabled is False
 
 
+def test_opt_out_env_var_overrides_yml_v013(tmp_path_factory, monkeypatch):
+    monkeypatch.delenv(
+        "GE_USAGE_STATS", raising=False
+    )  # Undo the project-wide test default
+    project_path = str(tmp_path_factory.mktemp("data_context"))
+    context_path = os.path.join(project_path, "great_expectations")
+    os.makedirs(context_path, exist_ok=True)
+    fixture_dir = file_relative_path(__file__, "../../test_fixtures")
+
+    shutil.copy(
+        os.path.join(
+            fixture_dir, "great_expectations_v013_basic_with_usage_stats_enabled.yml"
+        ),
+        str(os.path.join(context_path, "great_expectations.yml")),
+    )
+
+    assert (
+        DataContext(
+            context_root_dir=context_path
+        )._project_config.anonymous_usage_statistics.enabled
+        is True
+    )
+
+    monkeypatch.setenv("GE_USAGE_STATS", "False")
+    context = DataContext(context_root_dir=context_path)
+    project_config = context._project_config
+    assert project_config.anonymous_usage_statistics.enabled is False
+
+
 def test_opt_out_home_folder_overrides_etc(
     in_memory_data_context_config_usage_stats_enabled, tmp_path_factory, monkeypatch
 ):
@@ -404,6 +428,56 @@ def test_opt_out_home_folder_overrides_yml(tmp_path_factory, monkeypatch):
         assert project_config.anonymous_usage_statistics.enabled is False
 
 
+def test_opt_out_home_folder_overrides_yml_v013(tmp_path_factory, monkeypatch):
+    monkeypatch.delenv(
+        "GE_USAGE_STATS", raising=False
+    )  # Undo the project-wide test default
+    home_config_dir = tmp_path_factory.mktemp("home_dir")
+    home_config_dir = str(home_config_dir)
+    etc_config_dir = tmp_path_factory.mktemp("etc")
+    etc_config_dir = str(etc_config_dir)
+    config_dirs = [home_config_dir, etc_config_dir]
+    config_dirs = [
+        os.path.join(config_dir, "great_expectations.conf")
+        for config_dir in config_dirs
+    ]
+
+    disabled_config = configparser.ConfigParser()
+    disabled_config["anonymous_usage_statistics"] = {"enabled": "False"}
+
+    with open(
+        os.path.join(home_config_dir, "great_expectations.conf"), "w"
+    ) as configfile:
+        disabled_config.write(configfile)
+
+    project_path = str(tmp_path_factory.mktemp("data_context"))
+    context_path = os.path.join(project_path, "great_expectations")
+    os.makedirs(context_path, exist_ok=True)
+    fixture_dir = file_relative_path(__file__, "../../test_fixtures")
+
+    shutil.copy(
+        os.path.join(
+            fixture_dir, "great_expectations_v013_basic_with_usage_stats_enabled.yml"
+        ),
+        str(os.path.join(context_path, "great_expectations.yml")),
+    )
+
+    assert (
+        DataContext(
+            context_root_dir=context_path
+        )._project_config.anonymous_usage_statistics.enabled
+        is True
+    )
+
+    with mock.patch(
+        "great_expectations.data_context.BaseDataContext.GLOBAL_CONFIG_PATHS",
+        config_dirs,
+    ):
+        context = DataContext(context_root_dir=context_path)
+        project_config = context._project_config
+        assert project_config.anonymous_usage_statistics.enabled is False
+
+
 def test_opt_out_etc_overrides_yml(tmp_path_factory, monkeypatch):
     monkeypatch.delenv(
         "GE_USAGE_STATS", raising=False
@@ -452,3 +526,53 @@ def test_opt_out_etc_overrides_yml(tmp_path_factory, monkeypatch):
         context = DataContext(context_root_dir=context_path)
         project_config = context._project_config
         assert project_config.anonymous_usage_statistics.enabled is False
+
+
+def test_opt_out_etc_overrides_yml_v013(tmp_path_factory, monkeypatch):
+    monkeypatch.delenv(
+        "GE_USAGE_STATS", raising=False
+    )  # Undo the project-wide test default
+    home_config_dir = tmp_path_factory.mktemp("home_dir")
+    home_config_dir = str(home_config_dir)
+    etc_config_dir = tmp_path_factory.mktemp("etc")
+    etc_config_dir = str(etc_config_dir)
+    config_dirs = [home_config_dir, etc_config_dir]
+    config_dirs = [
+        os.path.join(config_dir, "great_expectations.conf")
+        for config_dir in config_dirs
+    ]
+
+    disabled_config = configparser.ConfigParser()
+    disabled_config["anonymous_usage_statistics"] = {"enabled": "False"}
+
+    with open(
+        os.path.join(etc_config_dir, "great_expectations.conf"), "w"
+    ) as configfile:
+        disabled_config.write(configfile)
+
+    project_path = str(tmp_path_factory.mktemp("data_context"))
+    context_path = os.path.join(project_path, "great_expectations")
+    os.makedirs(context_path, exist_ok=True)
+    fixture_dir = file_relative_path(__file__, "../../test_fixtures")
+
+    shutil.copy(
+        os.path.join(
+            fixture_dir, "great_expectations_v013_basic_with_usage_stats_enabled.yml"
+        ),
+        str(os.path.join(context_path, "great_expectations.yml")),
+    )
+
+    assert (
+        DataContext(
+            context_root_dir=context_path
+        )._project_config.anonymous_usage_statistics.enabled
+        is True
+    )
+
+    with mock.patch(
+        "great_expectations.data_context.BaseDataContext.GLOBAL_CONFIG_PATHS",
+        config_dirs,
+    ):
+        context = DataContext(context_root_dir=context_path)
+        project_config = context._project_config
+        assert project_config.anonymous_usage_statistics.enabled is False
