@@ -1,4 +1,5 @@
 import datetime
+from unittest import mock
 
 import boto3
 import pytest
@@ -16,6 +17,10 @@ from great_expectations.data_context.types.resource_identifiers import (
     ValidationResultIdentifier,
 )
 from great_expectations.util import gen_directory_tree_str
+from tests.core.usage_statistics.util import (
+    usage_stats_exceptions_exist,
+    usage_stats_invalid_messages_exist,
+)
 
 
 @freeze_time("09/26/2019 13:42:41")
@@ -295,3 +300,44 @@ def test_ValidationsStore_with_DatabaseStoreBackend(sa):
     assert my_store.store_backend_id is not None
     # Check that store_backend_id is a valid UUID
     assert test_utils.validate_uuid4(my_store.store_backend_id)
+
+
+@mock.patch(
+    "great_expectations.core.usage_statistics.usage_statistics.UsageStatisticsHandler.emit"
+)
+def test_instantiation_with_test_yaml_config(
+    mock_emit, caplog, empty_data_context_stats_enabled
+):
+    empty_data_context_stats_enabled.test_yaml_config(
+        yaml_config="""
+module_name: great_expectations.data_context.store.validations_store
+class_name: ValidationsStore
+store_backend:
+    class_name: TupleFilesystemStoreBackend
+    base_directory: uncommitted/validations/
+"""
+    )
+    assert mock_emit.call_count == 1
+    # Substitute current anonymized name since it changes for each run
+    anonymized_name = mock_emit.call_args_list[0][0][0]["event_payload"][
+        "anonymized_name"
+    ]
+    assert mock_emit.call_args_list == [
+        mock.call(
+            {
+                "event": "data_context.test_yaml_config",
+                "event_payload": {
+                    "anonymized_name": anonymized_name,
+                    "parent_class": "ValidationsStore",
+                    "anonymized_store_backend": {
+                        "parent_class": "TupleFilesystemStoreBackend"
+                    },
+                },
+                "success": True,
+            }
+        ),
+    ]
+
+    # Confirm that logs do not contain any exceptions or invalid messages
+    assert not usage_stats_exceptions_exist(messages=caplog.messages)
+    assert not usage_stats_invalid_messages_exist(messages=caplog.messages)
