@@ -16,7 +16,7 @@ from great_expectations.exceptions.exceptions import DatasourceInitializationErr
 @pytest.fixture
 def ge_cloud_data_context_config(
     ge_cloud_runtime_base_url,
-    ge_cloud_runtime_account_id,
+    ge_cloud_runtime_organization_id,
     ge_cloud_runtime_access_token,
 ):
     """
@@ -62,7 +62,7 @@ def ge_cloud_data_context_config(
           ge_cloud_resource_type: expectation_suite
           ge_cloud_credentials:
             access_token: {ge_cloud_runtime_access_token}
-            account_id: {ge_cloud_runtime_account_id}
+            organization_id: {ge_cloud_runtime_organization_id}
           suppress_store_backend_id: True
 
       default_validations_store:
@@ -73,7 +73,7 @@ def ge_cloud_data_context_config(
           ge_cloud_resource_type: suite_validation_result
           ge_cloud_credentials:
             access_token: {ge_cloud_runtime_access_token}
-            account_id: {ge_cloud_runtime_account_id}
+            organization_id: {ge_cloud_runtime_organization_id}
           suppress_store_backend_id: True
 
       default_checkpoint_store:
@@ -84,7 +84,7 @@ def ge_cloud_data_context_config(
           ge_cloud_resource_type: contract
           ge_cloud_credentials:
             access_token: {ge_cloud_runtime_access_token}
-            account_id: {ge_cloud_runtime_account_id}
+            organization_id: {ge_cloud_runtime_organization_id}
           suppress_store_backend_id: True
 
     evaluation_parameter_store_name: default_evaluation_parameter_store
@@ -102,7 +102,7 @@ def ge_cloud_data_context_config(
           ge_cloud_resource_type: rendered_data_doc
           ge_cloud_credentials:
             access_token: {ge_cloud_runtime_access_token}
-            account_id: {ge_cloud_runtime_account_id}
+            organization_id: {ge_cloud_runtime_organization_id}
           suppress_store_backend_id: True
         site_index_builder:
           class_name: DefaultSiteIndexBuilder
@@ -135,7 +135,7 @@ def test_data_context_ge_cloud_mode_with_incomplete_cloud_config_should_throw_er
 def test_data_context_ge_cloud_mode_makes_successful_request_to_cloud_api(
     mock_request,
     ge_cloud_runtime_base_url,
-    ge_cloud_runtime_account_id,
+    ge_cloud_runtime_organization_id,
     ge_cloud_runtime_access_token,
 ):
     # Ensure that the request goes through
@@ -144,13 +144,13 @@ def test_data_context_ge_cloud_mode_makes_successful_request_to_cloud_api(
         DataContext(
             ge_cloud_mode=True,
             ge_cloud_base_url=ge_cloud_runtime_base_url,
-            ge_cloud_account_id=ge_cloud_runtime_account_id,
+            ge_cloud_organization_id=ge_cloud_runtime_organization_id,
             ge_cloud_access_token=ge_cloud_runtime_access_token,
         )
     except:  # Not concerned with constructor output (only evaluating interaction with requests during __init__)
         pass
 
-    called_with_url = f"{ge_cloud_runtime_base_url}/accounts/{ge_cloud_runtime_account_id}/data-context-configuration"
+    called_with_url = f"{ge_cloud_runtime_base_url}/organizations/{ge_cloud_runtime_organization_id}/data-context-configuration"
     called_with_header = {
         "headers": {
             "Content-Type": "application/vnd.api+json",
@@ -168,7 +168,7 @@ def test_data_context_ge_cloud_mode_makes_successful_request_to_cloud_api(
 def test_data_context_ge_cloud_mode_with_bad_request_to_cloud_api_should_throw_error(
     mock_request,
     ge_cloud_runtime_base_url,
-    ge_cloud_runtime_account_id,
+    ge_cloud_runtime_organization_id,
     ge_cloud_runtime_access_token,
 ):
     # Ensure that the request fails
@@ -178,7 +178,7 @@ def test_data_context_ge_cloud_mode_with_bad_request_to_cloud_api_should_throw_e
         DataContext(
             ge_cloud_mode=True,
             ge_cloud_base_url=ge_cloud_runtime_base_url,
-            ge_cloud_account_id=ge_cloud_runtime_account_id,
+            ge_cloud_organization_id=ge_cloud_runtime_organization_id,
             ge_cloud_access_token=ge_cloud_runtime_access_token,
         )
 
@@ -186,7 +186,7 @@ def test_data_context_ge_cloud_mode_with_bad_request_to_cloud_api_should_throw_e
 def test_datasource_initialization_error_thrown_in_cloud_mode(
     ge_cloud_data_context_config: DataContextConfig,
     ge_cloud_runtime_base_url,
-    ge_cloud_runtime_account_id,
+    ge_cloud_runtime_organization_id,
     ge_cloud_runtime_access_token,
 ):
     # normally the DataContext swallows exceptions when there is an error raised from get_datasource
@@ -210,6 +210,6 @@ def test_datasource_initialization_error_thrown_in_cloud_mode(
                 DataContext(
                     ge_cloud_mode=True,
                     ge_cloud_base_url=ge_cloud_runtime_base_url,
-                    ge_cloud_account_id=ge_cloud_runtime_account_id,
+                    ge_cloud_organization_id=ge_cloud_runtime_organization_id,
                     ge_cloud_access_token=ge_cloud_runtime_access_token,
                 )
