@@ -8,8 +8,12 @@ from ruamel.yaml import YAML
 from great_expectations import DataContext
 from great_expectations.core import ExpectationSuite
 from great_expectations.core.batch import Batch, RuntimeBatchRequest
+from great_expectations.core.config_peer import ConfigOutputModes
 from great_expectations.data_context import BaseDataContext
-from great_expectations.data_context.types.base import DataContextConfig
+from great_expectations.data_context.types.base import (
+    DataContextConfig,
+    dataContextConfigSchema,
+)
 from great_expectations.exceptions import ExecutionEngineError
 from great_expectations.execution_engine.pandas_batch_data import PandasBatchData
 from great_expectations.execution_engine.sqlalchemy_batch_data import (
@@ -168,16 +172,17 @@ def test_get_config(empty_data_context):
 
     # We can call get_config in several different modes
     assert type(context.get_config()) == DataContextConfig
-    assert type(context.get_config(mode="typed")) == DataContextConfig
-    assert type(context.get_config(mode="dict")) == dict
+    assert type(context.get_config(mode=ConfigOutputModes.TYPED)) == DataContextConfig
+    assert type(context.get_config(mode=ConfigOutputModes.DICT)) == dict
+    assert type(context.get_config(mode=ConfigOutputModes.YAML)) == str
     assert type(context.get_config(mode="yaml")) == str
     with pytest.raises(ValueError):
         context.get_config(mode="foobar")
 
-    print(context.get_config(mode="yaml"))
-    print(context.get_config("dict").keys())
+    print(context.get_config(mode=ConfigOutputModes.YAML))
+    print(context.get_config(mode=ConfigOutputModes.DICT).keys())
 
-    assert set(context.get_config("dict").keys()) == {
+    assert set(context.get_config(mode=ConfigOutputModes.DICT).keys()) == {
         "config_version",
         "datasources",
         "config_variables_file_path",
@@ -189,7 +194,6 @@ def test_get_config(empty_data_context):
         "checkpoint_store_name",
         "data_docs_sites",
         "anonymous_usage_statistics",
-        "notebooks",
     }
 
 
@@ -458,7 +462,7 @@ def test_in_memory_data_context_configuration(
     titanic_pandas_data_context_with_v013_datasource_with_checkpoints_v1_with_empty_store_stats_enabled,
 ):
     project_config_dict: dict = titanic_pandas_data_context_with_v013_datasource_with_checkpoints_v1_with_empty_store_stats_enabled.get_config(
-        mode="dict"
+        mode=ConfigOutputModes.DICT
     )
     project_config_dict["plugins_directory"] = None
     project_config_dict["validation_operators"] = {
@@ -480,6 +484,11 @@ def test_in_memory_data_context_configuration(
             ],
         }
     }
+
+    # Roundtrip through schema validation to remove any illegal fields add/or restore any missing fields.
+    project_config_dict = dataContextConfigSchema.dump(project_config_dict)
+    project_config_dict = dataContextConfigSchema.load(project_config_dict)
+
     project_config: DataContextConfig = DataContextConfig(**project_config_dict)
     data_context = BaseDataContext(
         project_config=project_config,
