@@ -8,6 +8,9 @@ from great_expectations import DataContext
 from great_expectations.core.batch import BatchDefinition, BatchRequest, IDDict
 from great_expectations.data_context.util import instantiate_class_from_config
 from great_expectations.datasource.data_connector import InferredAssetGCSDataConnector
+from great_expectations.datasource.data_connector.inferred_asset_gcs_data_connector import (
+    storage,
+)
 from great_expectations.execution_engine import PandasExecutionEngine
 
 yaml = YAML()
@@ -36,6 +39,10 @@ def expected_config_dict():
     return config
 
 
+@pytest.mark.skipif(
+    storage is None,
+    reason="Could not import 'storage' from google.cloud in inferred_asset_gcs_data_connector.py",
+)
 @mock.patch(
     "great_expectations.datasource.data_connector.inferred_asset_gcs_data_connector.list_gcs_keys",
     return_value=[
@@ -69,6 +76,10 @@ def test_instantiation_without_args(
     assert my_data_connector.get_unmatched_data_references() == []
 
 
+@pytest.mark.skipif(
+    storage is None,
+    reason="Could not import 'storage' from google.cloud in inferred_asset_gcs_data_connector.py",
+)
 @mock.patch(
     "great_expectations.datasource.data_connector.inferred_asset_gcs_data_connector.list_gcs_keys",
     return_value=[
@@ -108,6 +119,10 @@ def test_instantiation_with_filename_arg(
     assert my_data_connector.get_unmatched_data_references() == []
 
 
+@pytest.mark.skipif(
+    storage is None,
+    reason="Could not import 'storage' from google.cloud in inferred_asset_gcs_data_connector.py",
+)
 @mock.patch(
     "great_expectations.datasource.data_connector.inferred_asset_gcs_data_connector.list_gcs_keys",
     return_value=[
@@ -147,6 +162,10 @@ def test_instantiation_with_info_arg(
     assert my_data_connector.get_unmatched_data_references() == []
 
 
+@pytest.mark.skipif(
+    storage is None,
+    reason="Could not import 'storage' from google.cloud in inferred_asset_gcs_data_connector.py",
+)
 @mock.patch(
     "great_expectations.core.usage_statistics.usage_statistics.UsageStatisticsHandler.emit"
 )
@@ -188,6 +207,10 @@ def test_get_batch_definition_list_from_batch_request_with_nonexistent_datasourc
         )
 
 
+@pytest.mark.skipif(
+    storage is None,
+    reason="Could not import 'storage' from google.cloud in inferred_asset_gcs_data_connector.py",
+)
 @mock.patch(
     "great_expectations.core.usage_statistics.usage_statistics.UsageStatisticsHandler.emit"
 )
@@ -234,6 +257,10 @@ def test_get_batch_definition_list_from_batch_request_with_unknown_data_connecto
         )
 
 
+@pytest.mark.skipif(
+    storage is None,
+    reason="Could not import 'storage' from google.cloud in inferred_asset_gcs_data_connector.py",
+)
 @mock.patch(
     "great_expectations.core.usage_statistics.usage_statistics.UsageStatisticsHandler.emit"
 )
@@ -291,6 +318,10 @@ def test_simple_regex_example_with_implicit_data_asset_names_self_check(
     }
 
 
+@pytest.mark.skipif(
+    storage is None,
+    reason="Could not import 'storage' from google.cloud in inferred_asset_gcs_data_connector.py",
+)
 @mock.patch(
     "great_expectations.core.usage_statistics.usage_statistics.UsageStatisticsHandler.emit"
 )
@@ -377,6 +408,10 @@ def test_complex_regex_example_with_implicit_data_asset_names(
     ]
 
 
+@pytest.mark.skipif(
+    storage is None,
+    reason="Could not import 'storage' from google.cloud in inferred_asset_gcs_data_connector.py",
+)
 @mock.patch(
     "great_expectations.core.usage_statistics.usage_statistics.UsageStatisticsHandler.emit"
 )
@@ -427,6 +462,10 @@ def test_self_check(mock_gcs_conn, mock_list_keys, mock_emit):
     }
 
 
+@pytest.mark.skipif(
+    storage is None,
+    reason="Could not import 'storage' from google.cloud in inferred_asset_gcs_data_connector.py",
+)
 @mock.patch(
     "great_expectations.core.usage_statistics.usage_statistics.UsageStatisticsHandler.emit"
 )
@@ -498,6 +537,10 @@ default_regex:
     }
 
 
+@pytest.mark.skipif(
+    storage is None,
+    reason="Could not import 'storage' from google.cloud in inferred_asset_gcs_data_connector.py",
+)
 @mock.patch(
     "great_expectations.core.usage_statistics.usage_statistics.UsageStatisticsHandler.emit"
 )
@@ -561,6 +604,10 @@ default_regex:
     assert mock_emit.call_args_list == expected_call_args_list
 
 
+@pytest.mark.skipif(
+    storage is None,
+    reason="Could not import 'storage' from google.cloud in inferred_asset_gcs_data_connector.py",
+)
 @mock.patch(
     "great_expectations.core.usage_statistics.usage_statistics.UsageStatisticsHandler.emit"
 )
@@ -636,6 +683,10 @@ default_regex:
     }
 
 
+@pytest.mark.skipif(
+    storage is None,
+    reason="Could not import 'storage' from google.cloud in inferred_asset_gcs_data_connector.py",
+)
 @mock.patch(
     "great_expectations.core.usage_statistics.usage_statistics.UsageStatisticsHandler.emit"
 )
@@ -708,6 +759,10 @@ def test_nested_directory_data_asset_name_in_folder(
     }
 
 
+@pytest.mark.skipif(
+    storage is None,
+    reason="Could not import 'storage' from google.cloud in inferred_asset_gcs_data_connector.py",
+)
 @mock.patch(
     "great_expectations.core.usage_statistics.usage_statistics.UsageStatisticsHandler.emit"
 )
@@ -772,6 +827,10 @@ def test_redundant_information_in_naming_convention_random_hash(
     }
 
 
+@pytest.mark.skipif(
+    storage is None,
+    reason="Could not import 'storage' from google.cloud in inferred_asset_gcs_data_connector.py",
+)
 @mock.patch(
     "great_expectations.core.usage_statistics.usage_statistics.UsageStatisticsHandler.emit"
 )
@@ -835,6 +894,10 @@ def test_redundant_information_in_naming_convention_timestamp(
     }
 
 
+@pytest.mark.skipif(
+    storage is None,
+    reason="Could not import 'storage' from google.cloud in inferred_asset_gcs_data_connector.py",
+)
 @mock.patch(
     "great_expectations.core.usage_statistics.usage_statistics.UsageStatisticsHandler.emit"
 )
@@ -899,6 +962,10 @@ def test_redundant_information_in_naming_convention_bucket(
     }
 
 
+@pytest.mark.skipif(
+    storage is None,
+    reason="Could not import 'storage' from google.cloud in inferred_asset_gcs_data_connector.py",
+)
 @mock.patch(
     "great_expectations.core.usage_statistics.usage_statistics.UsageStatisticsHandler.emit"
 )
@@ -1023,6 +1090,10 @@ def test_redundant_information_in_naming_convention_bucket_sorted(
     assert expected == sorted_batch_definition_list
 
 
+@pytest.mark.skipif(
+    storage is None,
+    reason="Could not import 'storage' from google.cloud in inferred_asset_gcs_data_connector.py",
+)
 @mock.patch(
     "great_expectations.core.usage_statistics.usage_statistics.UsageStatisticsHandler.emit"
 )
@@ -1081,6 +1152,10 @@ def test_redundant_information_in_naming_convention_bucket_sorter_does_not_match
         )
 
 
+@pytest.mark.skipif(
+    storage is None,
+    reason="Could not import 'storage' from google.cloud in inferred_asset_gcs_data_connector.py",
+)
 @mock.patch(
     "great_expectations.core.usage_statistics.usage_statistics.UsageStatisticsHandler.emit"
 )
@@ -1142,6 +1217,10 @@ def test_redundant_information_in_naming_convention_bucket_too_many_sorters(
         )
 
 
+@pytest.mark.skipif(
+    storage is None,
+    reason="Could not import 'storage' from google.cloud in inferred_asset_gcs_data_connector.py",
+)
 @mock.patch(
     "great_expectations.datasource.data_connector.inferred_asset_gcs_data_connector.storage.Client"
 )
