@@ -2,7 +2,6 @@ import jsonschema
 import pytest
 
 from great_expectations.core.expectation_suite import ExpectationSuite
-from great_expectations.profile.base import ProfilerTypeMapping
 from great_expectations.profile.json_schema_profiler import JsonSchemaProfiler
 
 
@@ -338,6 +337,14 @@ def test_profile_simple_schema(empty_data_context, simple_schema):
                     "uint16",
                     "uint32",
                     "uint64",
+                    "Int8Dtype",
+                    "Int16Dtype",
+                    "Int32Dtype",
+                    "Int64Dtype",
+                    "UInt8Dtype",
+                    "UInt16Dtype",
+                    "UInt32Dtype",
+                    "UInt64Dtype",
                     "INT",
                     "INTEGER",
                     "INT64",
@@ -757,6 +764,14 @@ def test_profile_integer_ranges_schema(empty_data_context, integer_ranges_schema
                     "uint16",
                     "uint32",
                     "uint64",
+                    "Int8Dtype",
+                    "Int16Dtype",
+                    "Int32Dtype",
+                    "Int64Dtype",
+                    "UInt8Dtype",
+                    "UInt16Dtype",
+                    "UInt32Dtype",
+                    "UInt64Dtype",
                     "INT",
                     "INTEGER",
                     "INT64",
@@ -797,6 +812,14 @@ def test_profile_integer_ranges_schema(empty_data_context, integer_ranges_schema
                     "uint16",
                     "uint32",
                     "uint64",
+                    "Int8Dtype",
+                    "Int16Dtype",
+                    "Int32Dtype",
+                    "Int64Dtype",
+                    "UInt8Dtype",
+                    "UInt16Dtype",
+                    "UInt32Dtype",
+                    "UInt64Dtype",
                     "INT",
                     "INTEGER",
                     "INT64",
@@ -842,6 +865,14 @@ def test_profile_integer_ranges_schema(empty_data_context, integer_ranges_schema
                     "uint16",
                     "uint32",
                     "uint64",
+                    "Int8Dtype",
+                    "Int16Dtype",
+                    "Int32Dtype",
+                    "Int64Dtype",
+                    "UInt8Dtype",
+                    "UInt16Dtype",
+                    "UInt32Dtype",
+                    "UInt64Dtype",
                     "INT",
                     "INTEGER",
                     "INT64",
@@ -887,6 +918,14 @@ def test_profile_integer_ranges_schema(empty_data_context, integer_ranges_schema
                     "uint16",
                     "uint32",
                     "uint64",
+                    "Int8Dtype",
+                    "Int16Dtype",
+                    "Int32Dtype",
+                    "Int64Dtype",
+                    "UInt8Dtype",
+                    "UInt16Dtype",
+                    "UInt32Dtype",
+                    "UInt64Dtype",
                     "INT",
                     "INTEGER",
                     "INT64",
@@ -932,6 +971,14 @@ def test_profile_integer_ranges_schema(empty_data_context, integer_ranges_schema
                     "uint16",
                     "uint32",
                     "uint64",
+                    "Int8Dtype",
+                    "Int16Dtype",
+                    "Int32Dtype",
+                    "Int64Dtype",
+                    "UInt8Dtype",
+                    "UInt16Dtype",
+                    "UInt32Dtype",
+                    "UInt64Dtype",
                     "INT",
                     "INTEGER",
                     "INT64",
@@ -977,6 +1024,14 @@ def test_profile_integer_ranges_schema(empty_data_context, integer_ranges_schema
                     "uint16",
                     "uint32",
                     "uint64",
+                    "Int8Dtype",
+                    "Int16Dtype",
+                    "Int32Dtype",
+                    "Int64Dtype",
+                    "UInt8Dtype",
+                    "UInt16Dtype",
+                    "UInt32Dtype",
+                    "UInt64Dtype",
                     "INT",
                     "INTEGER",
                     "INT64",
@@ -1026,6 +1081,14 @@ def test_profile_integer_ranges_schema(empty_data_context, integer_ranges_schema
                     "uint16",
                     "uint32",
                     "uint64",
+                    "Int8Dtype",
+                    "Int16Dtype",
+                    "Int32Dtype",
+                    "Int64Dtype",
+                    "UInt8Dtype",
+                    "UInt16Dtype",
+                    "UInt32Dtype",
+                    "UInt64Dtype",
                     "INT",
                     "INTEGER",
                     "INT64",
@@ -1075,6 +1138,14 @@ def test_profile_integer_ranges_schema(empty_data_context, integer_ranges_schema
                     "uint16",
                     "uint32",
                     "uint64",
+                    "Int8Dtype",
+                    "Int16Dtype",
+                    "Int32Dtype",
+                    "Int64Dtype",
+                    "UInt8Dtype",
+                    "UInt16Dtype",
+                    "UInt32Dtype",
+                    "UInt64Dtype",
                     "INT",
                     "INTEGER",
                     "INT64",
@@ -1126,6 +1197,14 @@ def test_profile_integer_ranges_schema(empty_data_context, integer_ranges_schema
                     "uint16",
                     "uint32",
                     "uint64",
+                    "Int8Dtype",
+                    "Int16Dtype",
+                    "Int32Dtype",
+                    "Int64Dtype",
+                    "UInt8Dtype",
+                    "UInt16Dtype",
+                    "UInt32Dtype",
+                    "UInt64Dtype",
                     "INT",
                     "INTEGER",
                     "INT64",
@@ -1635,6 +1714,14 @@ def test_has_profile_create_expectations_from_complex_schema(
                     "uint16",
                     "uint32",
                     "uint64",
+                    "Int8Dtype",
+                    "Int16Dtype",
+                    "Int32Dtype",
+                    "Int64Dtype",
+                    "UInt8Dtype",
+                    "UInt16Dtype",
+                    "UInt32Dtype",
+                    "UInt64Dtype",
                     "INT",
                     "INTEGER",
                     "INT64",
@@ -1846,6 +1933,14 @@ def test_null_fields_schema(empty_data_context, null_fields_schema):
                     "uint16",
                     "uint32",
                     "uint64",
+                    "Int8Dtype",
+                    "Int16Dtype",
+                    "Int32Dtype",
+                    "Int64Dtype",
+                    "UInt8Dtype",
+                    "UInt16Dtype",
+                    "UInt32Dtype",
+                    "UInt64Dtype",
                     "INT",
                     "INTEGER",
                     "INT64",
